Class: Aws::CloudFront::Types::CachePolicyList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CachePolicyList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of cache policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::CachePolicySummary>
Contains the cache policies in the list.
-
#max_items ⇒ Integer
The maximum number of cache policies requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The total number of cache policies returned in the response.
Instance Attribute Details
#items ⇒ Array<Types::CachePolicySummary>
Contains the cache policies in the list.
1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1279 class CachePolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of cache policies requested.
1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1279 class CachePolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing cache policies where you left off.
1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1279 class CachePolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The total number of cache policies returned in the response.
1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1279 class CachePolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |