Class: Aws::CloudFront::Types::CloudFrontOriginAccessIdentityList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CloudFrontOriginAccessIdentityList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Lists the origin access identities for CloudFront.Send a GET request to the ‘/CloudFront API version/origin-access-identity/cloudfront` resource. The response includes a CloudFrontOriginAccessIdentityList element with zero or more CloudFrontOriginAccessIdentitySummary child elements. By default, your entire list of origin access identities is returned in one single page. If the list is long, you can paginate it using the MaxItems and Marker parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more origin access identities remain to be listed.
-
#items ⇒ Array<Types::CloudFrontOriginAccessIdentitySummary>
A complex type that contains one
CloudFrontOriginAccessIdentitySummaryelement for each origin access identity that was created by the current Amazon Web Services account. -
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of origin access identities.
-
#max_items ⇒ Integer
The maximum number of origin access identities you want in the response body.
-
#next_marker ⇒ String
If
IsTruncatedistrue, this element is present and contains the value you can use for theMarkerrequest parameter to continue listing your origin access identities where they left off. -
#quantity ⇒ Integer
The number of CloudFront origin access identities that were created by the current Amazon Web Services account.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more origin access identities remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more items in the list.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::CloudFrontOriginAccessIdentitySummary>
A complex type that contains one CloudFrontOriginAccessIdentitySummary element for each origin access identity that was created by the current Amazon Web Services account.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of origin access identities. The results include identities in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page’s response (which is also the ID of the last identity on that page).
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin access identities you want in the response body.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your origin access identities where they left off.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of CloudFront origin access identities that were created by the current Amazon Web Services account.
1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1590 class CloudFrontOriginAccessIdentityList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |