Class: Aws::CloudFront::Types::CloudFrontOriginAccessIdentitySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Summary of the information about a CloudFront origin access identity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commentString

The comment for this origin access identity, as originally specified when created.



1643
1644
1645
1646
1647
1648
1649
# File 'lib/aws-sdk-cloudfront/types.rb', line 1643

class CloudFrontOriginAccessIdentitySummary < Struct.new(
  :id,
  :s3_canonical_user_id,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID for the origin access identity. For example: E74FTE3AJFJ256A.



1643
1644
1645
1646
1647
1648
1649
# File 'lib/aws-sdk-cloudfront/types.rb', line 1643

class CloudFrontOriginAccessIdentitySummary < Struct.new(
  :id,
  :s3_canonical_user_id,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#s3_canonical_user_idString

The Amazon S3 canonical user ID for the origin access identity, which you use when giving the origin access identity read permission to an object in Amazon S3.



1643
1644
1645
1646
1647
1648
1649
# File 'lib/aws-sdk-cloudfront/types.rb', line 1643

class CloudFrontOriginAccessIdentitySummary < Struct.new(
  :id,
  :s3_canonical_user_id,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end