Class: Aws::CloudFront::Types::ConflictingAlias

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

An alias (also called a CNAME) and the CloudFront standard distribution and Amazon Web Services account ID that it’s associated with. The standard distribution and account IDs are partially hidden, which allows you to identify the standard distributions and accounts that you own, and helps to protect the information of ones that you don’t own.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The (partially hidden) ID of the Amazon Web Services account that owns the standard distribution that’s associated with the alias.

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-cloudfront/types.rb', line 1674

class ConflictingAlias < Struct.new(
  :alias,
  :distribution_id,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#aliasString

An alias (also called a CNAME).

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-cloudfront/types.rb', line 1674

class ConflictingAlias < Struct.new(
  :alias,
  :distribution_id,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_idString

The (partially hidden) ID of the CloudFront standard distribution associated with the alias.

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-cloudfront/types.rb', line 1674

class ConflictingAlias < Struct.new(
  :alias,
  :distribution_id,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end