Class: Aws::CloudFront::Types::ConnectionGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The connection group for your distribution tenants. When you first create a distribution tenant and you don't specify a connection group, CloudFront will automatically create a default connection group for you. When you create a new distribution tenant and don't specify a connection group, the default one will be associated with your distribution tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anycast_ip_list_idString

The ID of the Anycast static IP list.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the connection group.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The date and time when the connection group was created.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Whether the connection group is enabled.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the connection group.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_enabledBoolean

IPv6 is enabled for the connection group.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Whether the connection group is the default connection group for the distribution tenants.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time when the connection group was updated.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connection group.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#routing_endpointString

The routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the connection group.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#tagsTypes::Tags

A complex type that contains zero or more Tag elements.



1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-cloudfront/types.rb', line 1875

class ConnectionGroup < Struct.new(
  :id,
  :name,
  :arn,
  :created_time,
  :last_modified_time,
  :tags,
  :ipv_6_enabled,
  :routing_endpoint,
  :anycast_ip_list_id,
  :status,
  :enabled,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end