Class: Aws::CloudFront::Types::ConnectionGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ConnectionGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A summary that contains details about your connection groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the connection group.
-
#created_time ⇒ Time
The date and time when the connection group was created.
-
#enabled ⇒ Boolean
Whether the connection group is enabled.
-
#etag ⇒ String
The current version of the connection group.
-
#id ⇒ String
The ID of the connection group.
-
#is_default ⇒ Boolean
Whether the connection group is the default connection group for the distribution tenants.
-
#last_modified_time ⇒ Time
The date and time when the connection group was updated.
-
#name ⇒ String
The name of the connection group.
-
#routing_endpoint ⇒ String
The routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.
-
#status ⇒ String
The status of the connection group.
Instance Attribute Details
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the connection group.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The date and time when the connection group was created.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Whether the connection group is enabled
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current version of the connection group.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the connection group.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Whether the connection group is the default connection group for the distribution tenants.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time when the connection group was updated.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connection group.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#routing_endpoint ⇒ String
The routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the connection group.
1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 1957 class ConnectionGroupSummary < Struct.new( :id, :name, :arn, :routing_endpoint, :created_time, :last_modified_time, :etag, :anycast_ip_list_id, :enabled, :status, :is_default) SENSITIVE = [] include Aws::Structure end |