Class: Aws::CloudFront::Types::CreateConnectionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CreateConnectionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
-
#enabled ⇒ Boolean
Enable the connection group.
-
#ipv_6_enabled ⇒ Boolean
Enable IPv6 for the connection group.
-
#name ⇒ String
The name of the connection group.
-
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
Instance Attribute Details
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2625 class CreateConnectionGroupRequest < Struct.new( :name, :ipv_6_enabled, :tags, :anycast_ip_list_id, :enabled) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Enable the connection group.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2625 class CreateConnectionGroupRequest < Struct.new( :name, :ipv_6_enabled, :tags, :anycast_ip_list_id, :enabled) SENSITIVE = [] include Aws::Structure end |
#ipv_6_enabled ⇒ Boolean
Enable IPv6 for the connection group. The default is ‘true`. For more information, see [Enable IPv6] in the *Amazon CloudFront Developer Guide*.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2625 class CreateConnectionGroupRequest < Struct.new( :name, :ipv_6_enabled, :tags, :anycast_ip_list_id, :enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connection group. Enter a friendly identifier that is unique within your Amazon Web Services account. This name can’t be updated after you create the connection group.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2625 class CreateConnectionGroupRequest < Struct.new( :name, :ipv_6_enabled, :tags, :anycast_ip_list_id, :enabled) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2625 class CreateConnectionGroupRequest < Struct.new( :name, :ipv_6_enabled, :tags, :anycast_ip_list_id, :enabled) SENSITIVE = [] include Aws::Structure end |