Class: Aws::CloudFront::Types::CreateKeyValueStoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CreateKeyValueStoreRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ String
The comment of the key value store.
-
#import_source ⇒ Types::ImportSource
The S3 bucket that provides the source for the import.
-
#name ⇒ String
The name of the key value store.
-
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
Instance Attribute Details
#comment ⇒ String
The comment of the key value store.
3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3107 class CreateKeyValueStoreRequest < Struct.new( :name, :comment, :import_source, :tags) SENSITIVE = [] include Aws::Structure end |
#import_source ⇒ Types::ImportSource
The S3 bucket that provides the source for the import. The source must be in a valid JSON format.
3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3107 class CreateKeyValueStoreRequest < Struct.new( :name, :comment, :import_source, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the key value store. The minimum length is 1 character and the maximum length is 64 characters.
3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3107 class CreateKeyValueStoreRequest < Struct.new( :name, :comment, :import_source, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3107 class CreateKeyValueStoreRequest < Struct.new( :name, :comment, :import_source, :tags) SENSITIVE = [] include Aws::Structure end |