Class: Aws::CloudFront::Types::CreateTrustStoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CreateTrustStoreRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source for the trust store.
-
#name ⇒ String
A name for the trust store.
-
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
-
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether to use the CA certificate’s OCSP endpoint to check certificate revocation status.
Instance Attribute Details
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source for the trust store.
3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3457 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the trust store.
3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3457 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3457 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :tags) SENSITIVE = [] include Aws::Structure end |
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether to use the CA certificate’s OCSP endpoint to check certificate revocation status.
3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3457 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :tags) SENSITIVE = [] include Aws::Structure end |