Class: Aws::CloudFront::Types::CustomOriginConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CustomOriginConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A custom origin. A custom origin is any origin that is not an Amazon S3 bucket, with one exception. An Amazon S3 bucket that is [configured with static website hosting] is a custom origin.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_port ⇒ Integer
The HTTP port that CloudFront uses to connect to the origin.
-
#https_port ⇒ Integer
The HTTPS port that CloudFront uses to connect to the origin.
-
#ip_address_type ⇒ String
Specifies which IP protocol CloudFront uses when connecting to your origin.
-
#origin_keepalive_timeout ⇒ Integer
Specifies how long, in seconds, CloudFront persists its connection to the origin.
-
#origin_mtls_config ⇒ Types::OriginMtlsConfig
Configures mutual TLS authentication between CloudFront and your origin server.
-
#origin_protocol_policy ⇒ String
Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
-
#origin_read_timeout ⇒ Integer
Specifies how long, in seconds, CloudFront waits for a response from the origin.
-
#origin_ssl_protocols ⇒ Types::OriginSslProtocols
Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.
Instance Attribute Details
#http_port ⇒ Integer
The HTTP port that CloudFront uses to connect to the origin. Specify the HTTP port that the origin listens on.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#https_port ⇒ Integer
The HTTPS port that CloudFront uses to connect to the origin. Specify the HTTPS port that the origin listens on.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
Specifies which IP protocol CloudFront uses when connecting to your origin. If your origin uses both IPv4 and IPv6 protocols, you can choose ‘dualstack` to help optimize reliability.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#origin_keepalive_timeout ⇒ Integer
Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don’t specify otherwise) is 5 seconds.
For more information, see [Keep-alive timeout (custom origins only)] in the *Amazon CloudFront Developer Guide*.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#origin_mtls_config ⇒ Types::OriginMtlsConfig
Configures mutual TLS authentication between CloudFront and your origin server.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#origin_protocol_policy ⇒ String
Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values are:
-
‘http-only` – CloudFront always uses HTTP to connect to the origin.
-
‘match-viewer` – CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront.
-
‘https-only` – CloudFront always uses HTTPS to connect to the origin.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#origin_read_timeout ⇒ Integer
Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the *origin response timeout*. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don’t specify otherwise) is 30 seconds.
For more information, see [Response timeout] in the *Amazon CloudFront Developer Guide*.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |
#origin_ssl_protocols ⇒ Types::OriginSslProtocols
Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS. Valid values include ‘SSLv3`, `TLSv1`, `TLSv1.1`, and `TLSv1.2`.
For more information, see [Minimum Origin SSL Protocol] in the *Amazon CloudFront Developer Guide*.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3749 class CustomOriginConfig < Struct.new( :http_port, :https_port, :origin_protocol_policy, :origin_ssl_protocols, :origin_read_timeout, :origin_keepalive_timeout, :ip_address_type, :origin_mtls_config) SENSITIVE = [] include Aws::Structure end |