Class: Aws::CloudFront::Types::Customizations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Customizations for the distribution tenant. For each distribution tenant, you can specify the geographic restrictions, and the Amazon Resource Names (ARNs) for the ACM certificate and WAF web ACL. These are specific values that you can override or disable from the multi-tenant distribution that was used to create the distribution tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificateTypes::Certificate

The Certificate Manager (ACM) certificate.

Returns:



3799
3800
3801
3802
3803
3804
3805
# File 'lib/aws-sdk-cloudfront/types.rb', line 3799

class Customizations < Struct.new(
  :web_acl,
  :certificate,
  :geo_restrictions)
  SENSITIVE = []
  include Aws::Structure
end

#geo_restrictionsTypes::GeoRestrictionCustomization

The geographic restrictions.



3799
3800
3801
3802
3803
3804
3805
# File 'lib/aws-sdk-cloudfront/types.rb', line 3799

class Customizations < Struct.new(
  :web_acl,
  :certificate,
  :geo_restrictions)
  SENSITIVE = []
  include Aws::Structure
end

#web_aclTypes::WebAclCustomization

The WAF web ACL.



3799
3800
3801
3802
3803
3804
3805
# File 'lib/aws-sdk-cloudfront/types.rb', line 3799

class Customizations < Struct.new(
  :web_acl,
  :certificate,
  :geo_restrictions)
  SENSITIVE = []
  include Aws::Structure
end