Class: Aws::CloudFront::Types::DeleteDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DeleteDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
This action deletes a web distribution. To delete a web distribution using the CloudFront API, perform the following steps.
To delete a web distribution using the CloudFront API:
-
Disable the web distribution
-
Submit a
GET Distribution Configrequest to get the current configuration and theEtagheader for the distribution. -
Update the XML document that was returned in the response to your
GET Distribution Configrequest to change the value ofEnabledtofalse. -
Submit a
PUT Distribution Configrequest to update the configuration for your distribution. In the request body, include the XML document that you updated in Step 3. Set the value of the HTTPIf-Matchheader to the value of theETagheader that CloudFront returned when you submitted theGET Distribution Configrequest in Step 2. -
Review the response to the
PUT Distribution Configrequest to confirm that the distribution was successfully disabled. -
Submit a
GET Distributionrequest to confirm that your changes have propagated. When propagation is complete, the value ofStatusisDeployed. -
Submit a
DELETE Distributionrequest. Set the value of the HTTPIf-Matchheader to the value of theETagheader that CloudFront returned when you submitted theGET Distribution Configrequest in Step 6. -
Review the response to your
DELETE Distributionrequest to confirm that the distribution was successfully deleted.
For information about deleting a distribution using the CloudFront console, see Deleting a Distribution in the Amazon CloudFront Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The distribution ID.
-
#if_match ⇒ String
The value of the
ETagheader that you received when you disabled the distribution.
Instance Attribute Details
#id ⇒ String
The distribution ID.
4339 4340 4341 4342 4343 4344 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 4339 class DeleteDistributionRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The value of the ETag header that you received when you disabled
the distribution. For example: E2QWRUHAPOMQZL.
4339 4340 4341 4342 4343 4344 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 4339 class DeleteDistributionRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |