Class: Aws::CloudFront::Types::DeleteFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DeleteFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#if_match ⇒ String
The current version (
ETagvalue) of the function that you are deleting, which you can get usingDescribeFunction. -
#name ⇒ String
The name of the function that you are deleting.
Instance Attribute Details
#if_match ⇒ String
The current version (ETag value) of the function that you are deleting, which you can get using DescribeFunction.
3169 3170 3171 3172 3173 3174 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3169 class DeleteFunctionRequest < Struct.new( :name, :if_match) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the function that you are deleting.
3169 3170 3171 3172 3173 3174 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3169 class DeleteFunctionRequest < Struct.new( :name, :if_match) SENSITIVE = [] include Aws::Structure end |