Class: Aws::CloudFront::Types::DeleteResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DeleteResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the CloudFront resource for which the resource policy should be deleted.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the CloudFront resource for which the resource policy should be deleted.
4540 4541 4542 4543 4544 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 4540 class DeleteResourcePolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |