Class: Aws::CloudFront::Types::DistributionIdList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DistributionIdList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of distribution IDs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more distribution IDs remain to be listed.
-
#items ⇒ Array<String>
Contains the distribution IDs in the list.
-
#marker ⇒ String
The value provided in the
Markerrequest field. -
#max_items ⇒ Integer
The maximum number of distribution IDs requested.
-
#next_marker ⇒ String
Contains the value that you should use in the
Markerfield of a subsequent request to continue listing distribution IDs where you left off. -
#quantity ⇒ Integer
The total number of distribution IDs returned in the response.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more distribution IDs remain to be listed. If your results were truncated, you can make a subsequent request using the Marker request field to retrieve more distribution IDs in the list.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<String>
Contains the distribution IDs in the list.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The value provided in the Marker request field.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution IDs requested.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
Contains the value that you should use in the Marker field of a subsequent request to continue listing distribution IDs where you left off.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The total number of distribution IDs returned in the response.
5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5326 class DistributionIdList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |