Class: Aws::CloudFront::Types::DistributionIdOwnerList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The list of distribution IDs and the Amazon Web Services accounts that they belong to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether more DistributionIdOwner objects remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more results in the list.

Returns:

  • (Boolean)


5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::DistributionIdOwner>

The number of DistributionIdOwner objects.

Returns:



5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in your list of DistributionIdOwner objects. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of DistributionIdOwner objects to return.

Returns:

  • (Integer)


5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.

Returns:

  • (String)


5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

Specifies the actual number of DistributionIdOwner objects included in the list for the current page.

Returns:

  • (Integer)


5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397

class DistributionIdOwnerList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end