Class: Aws::CloudFront::Types::DistributionList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A distribution list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether more distributions remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more distributions in the list.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::DistributionSummary>

A complex type that contains one DistributionSummary element for each distribution that was created by the current Amazon Web Services account.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The value you provided for the Marker request parameter.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The value you provided for the MaxItems request parameter.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your distributions where they left off.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of distributions that were created by the current Amazon Web Services account.

Returns:



5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
# File 'lib/aws-sdk-cloudfront/types.rb', line 5504

class DistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end