Class: Aws::CloudFront::Types::DistributionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A summary of the information about a CloudFront distribution.

Constant Summary collapse

SENSITIVE =
[:comment]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_icp_recordalsArray<Types::AliasICPRecordal>

Amazon Web Services services in China customers must file for an Internet Content Provider (ICP) recordal if they want to serve content publicly on an alternate domain name, also known as a CNAME, that they’ve added to CloudFront. AliasICPRecordal provides the ICP recordal status for CNAMEs associated with distributions.

For more information about ICP recordals, see [ Signup, Accounts, and Credentials] in *Getting Started with Amazon Web Services services in China*.

[1]: docs.amazonaws.cn/en_us/aws/latest/userguide/accounts-and-credentials.html

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#aliasesTypes::Aliases

A complex type that contains information about CNAMEs (alternate domain names), if any, for this distribution.

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#anycast_ip_list_idString

ID of the Anycast static IP list that is associated with the distribution.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#arnString

The ARN (Amazon Resource Name) for the distribution. For example: ‘arn:aws:cloudfront::123456789012:distribution/EDFDVBD632BHDS5`, where `123456789012` is your Amazon Web Services account ID.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#cache_behaviorsTypes::CacheBehaviors

A complex type that contains zero or more ‘CacheBehavior` elements.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#commentString

The comment originally specified when this distribution was created.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#connection_function_associationTypes::ConnectionFunctionAssociation

The distribution’s connection function association.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#connection_modeString

This field specifies whether the connection mode is through a standard distribution (direct) or a multi-tenant distribution with distribution tenants (tenant-only).

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#custom_error_responsesTypes::CustomErrorResponses

A complex type that contains zero or more ‘CustomErrorResponses` elements.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#default_cache_behaviorTypes::DefaultCacheBehavior

A complex type that describes the default cache behavior if you don’t specify a ‘CacheBehavior` element or if files don’t match any of the values of ‘PathPattern` in `CacheBehavior` elements. You must create exactly one default cache behavior.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#domain_nameString

The domain name that corresponds to the distribution, for example, ‘d111111abcdef8.cloudfront.net`.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#enabledBoolean

Whether the distribution is enabled to accept user requests for content.

Returns:

  • (Boolean)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#etagString

The current version of the distribution.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#http_versionString

Specify the maximum HTTP version that you want viewers to use to communicate with CloudFront. The default value for new web distributions is ‘http2`. Viewers that don’t support ‘HTTP/2` will automatically use an earlier version.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#idString

The identifier for the distribution. For example: ‘EDFDVBD632BHDS5`.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#is_ipv6_enabledBoolean

Whether CloudFront responds to IPv6 DNS requests with an IPv6 address for your distribution.

Returns:

  • (Boolean)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#last_modified_timeTime

The date and time the distribution was last modified.

Returns:

  • (Time)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#origin_groupsTypes::OriginGroups

A complex type that contains information about origin groups for this distribution.

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#originsTypes::Origins

A complex type that contains information about origins for this distribution.

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#price_classString

<note markdown=“1”> This field only supports standard distributions. You can’t specify this field for multi-tenant distributions. For more information, see

Unsupported features for SaaS Manager for Amazon CloudFront][1

in

the *Amazon CloudFront Developer Guide*.

</note>

A complex type that contains information about price class for this

streaming distribution.

[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-config-options.html#unsupported-saas

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#restrictionsTypes::Restrictions

A complex type that identifies ways in which you want to restrict distribution of your content.

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#stagingBoolean

A Boolean that indicates whether this is a staging distribution. When this value is ‘true`, this is a staging distribution. When this value is `false`, this is not a staging distribution.

Returns:

  • (Boolean)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#statusString

The current status of the distribution. When the status is ‘Deployed`, the distribution’s information is propagated to all CloudFront edge locations.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#viewer_certificateTypes::ViewerCertificate

A complex type that determines the distribution’s SSL/TLS configuration for communicating with viewers.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#viewer_mtls_configTypes::ViewerMtlsConfig

The distribution’s viewer mTLS configuration.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end

#web_acl_idString

The Web ACL Id (if any) associated with the distribution.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-cloudfront/types.rb', line 5689

class DistributionSummary < Struct.new(
  :id,
  :arn,
  :etag,
  :status,
  :last_modified_time,
  :domain_name,
  :aliases,
  :origins,
  :origin_groups,
  :default_cache_behavior,
  :cache_behaviors,
  :custom_error_responses,
  :comment,
  :price_class,
  :enabled,
  :viewer_certificate,
  :restrictions,
  :web_acl_id,
  :http_version,
  :is_ipv6_enabled,
  :alias_icp_recordals,
  :staging,
  :connection_mode,
  :anycast_ip_list_id,
  :viewer_mtls_config,
  :connection_function_association)
  SENSITIVE = [:comment]
  include Aws::Structure
end