Class: Aws::CloudFront::Types::DnsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DnsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The DNS configuration for your domain names.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain name that you’re verifying.
-
#reason ⇒ String
Explains the status of the DNS configuration.
-
#status ⇒ String
The status of your domain name.
Instance Attribute Details
#domain ⇒ String
The domain name that you’re verifying.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5942 class DnsConfiguration < Struct.new( :domain, :status, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
Explains the status of the DNS configuration.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5942 class DnsConfiguration < Struct.new( :domain, :status, :reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of your domain name.
-
‘valid-configuration`: The domain name is correctly configured and points to the correct routing endpoint of the connection group.
-
‘invalid-configuration`: There is either a missing DNS record or the DNS record exists but it’s using an incorrect routing endpoint. Update the DNS record to point to the correct routing endpoint.
-
‘unknown-configuration`: CloudFront can’t validate your DNS configuration. This status can appear if CloudFront can’t verify the DNS record, or the DNS lookup request failed or timed out.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5942 class DnsConfiguration < Struct.new( :domain, :status, :reason) SENSITIVE = [] include Aws::Structure end |