Class: Aws::CloudFront::Types::EncryptionEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Complex data type for field-level encryption profiles that includes the encryption key and field pattern specifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_patternsTypes::FieldPatterns

Field patterns in a field-level encryption content type profile specify the fields that you want to be encrypted. You can provide the full field name, or any beginning characters followed by a wildcard (*). You can’t overlap field patterns. For example, you can’t have both ABC* and AB*. Note that field patterns are case-sensitive.



6063
6064
6065
6066
6067
6068
6069
# File 'lib/aws-sdk-cloudfront/types.rb', line 6063

class EncryptionEntity < Struct.new(
  :public_key_id,
  :provider_id,
  :field_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#provider_idString

The provider associated with the public key being used for encryption. This value must also be provided with the private key for applications to be able to decrypt data.

Returns:

  • (String)


6063
6064
6065
6066
6067
6068
6069
# File 'lib/aws-sdk-cloudfront/types.rb', line 6063

class EncryptionEntity < Struct.new(
  :public_key_id,
  :provider_id,
  :field_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_idString

The public key associated with a set of field-level encryption patterns, to be used when encrypting the fields that match the patterns.

Returns:

  • (String)


6063
6064
6065
6066
6067
6068
6069
# File 'lib/aws-sdk-cloudfront/types.rb', line 6063

class EncryptionEntity < Struct.new(
  :public_key_id,
  :provider_id,
  :field_patterns)
  SENSITIVE = []
  include Aws::Structure
end