Class: Aws::CloudFront::Types::FieldLevelEncryptionList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

List of field-level encryption configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::FieldLevelEncryptionSummary>

An array of field-level encryption items.



6263
6264
6265
6266
6267
6268
6269
6270
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263

class FieldLevelEncryptionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of elements you want in the response body.

Returns:

  • (Integer)


6263
6264
6265
6266
6267
6268
6269
6270
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263

class FieldLevelEncryptionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more elements to be listed, this element is present and contains the value that you can use for the Marker request parameter to continue listing your configurations where you left off.

Returns:

  • (String)


6263
6264
6265
6266
6267
6268
6269
6270
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263

class FieldLevelEncryptionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of field-level encryption items.

Returns:

  • (Integer)


6263
6264
6265
6266
6267
6268
6269
6270
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263

class FieldLevelEncryptionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end