Class: Aws::CloudFront::Types::FieldLevelEncryptionProfileSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::FieldLevelEncryptionProfileSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The field-level encryption profile summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ String
An optional comment for the field-level encryption profile summary.
-
#encryption_entities ⇒ Types::EncryptionEntities
A complex data type of encryption entities for the field-level encryption profile that include the public key ID, provider, and field patterns for specifying which fields to encrypt with this key.
-
#id ⇒ String
ID for the field-level encryption profile summary.
-
#last_modified_time ⇒ Time
The time when the field-level encryption profile summary was last updated.
-
#name ⇒ String
Name for the field-level encryption profile summary.
Instance Attribute Details
#comment ⇒ String
An optional comment for the field-level encryption profile summary. The comment cannot be longer than 128 characters.
6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6430 class FieldLevelEncryptionProfileSummary < Struct.new( :id, :last_modified_time, :name, :encryption_entities, :comment) SENSITIVE = [] include Aws::Structure end |
#encryption_entities ⇒ Types::EncryptionEntities
A complex data type of encryption entities for the field-level encryption profile that include the public key ID, provider, and field patterns for specifying which fields to encrypt with this key.
6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6430 class FieldLevelEncryptionProfileSummary < Struct.new( :id, :last_modified_time, :name, :encryption_entities, :comment) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
ID for the field-level encryption profile summary.
6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6430 class FieldLevelEncryptionProfileSummary < Struct.new( :id, :last_modified_time, :name, :encryption_entities, :comment) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the field-level encryption profile summary was last updated.
6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6430 class FieldLevelEncryptionProfileSummary < Struct.new( :id, :last_modified_time, :name, :encryption_entities, :comment) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name for the field-level encryption profile summary.
6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6430 class FieldLevelEncryptionProfileSummary < Struct.new( :id, :last_modified_time, :name, :encryption_entities, :comment) SENSITIVE = [] include Aws::Structure end |