Class: Aws::CloudFront::Types::FunctionList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of CloudFront functions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::FunctionSummary>

Contains the functions in the list.

Returns:



6781
6782
6783
6784
6785
6786
6787
6788
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781

class FunctionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of functions requested.

Returns:

  • (Integer)


6781
6782
6783
6784
6785
6786
6787
6788
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781

class FunctionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing functions where you left off.

Returns:

  • (String)


6781
6782
6783
6784
6785
6786
6787
6788
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781

class FunctionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of functions returned in the response.

Returns:

  • (Integer)


6781
6782
6783
6784
6785
6786
6787
6788
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781

class FunctionList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end