Class: Aws::CloudFront::Types::GeoRestrictionCustomization

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The customizations that you specified for the distribution tenant for geographic restrictions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#locationsArray<String>

The locations for geographic restrictions.

Returns:

  • (Array<String>)


6931
6932
6933
6934
6935
6936
# File 'lib/aws-sdk-cloudfront/types.rb', line 6931

class GeoRestrictionCustomization < Struct.new(
  :restriction_type,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end

#restriction_typeString

The method that you want to use to restrict distribution of your content by country:

  • ‘none`: No geographic restriction is enabled, meaning access to content is not restricted by client geo location.

  • ‘blacklist`: The `Location` elements specify the countries in which you don’t want CloudFront to distribute your content.

  • ‘whitelist`: The `Location` elements specify the countries in which you want CloudFront to distribute your content.

Returns:

  • (String)


6931
6932
6933
6934
6935
6936
# File 'lib/aws-sdk-cloudfront/types.rb', line 6931

class GeoRestrictionCustomization < Struct.new(
  :restriction_type,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end