Class: Aws::CloudFront::Types::GetOriginRequestPolicyConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::GetOriginRequestPolicyConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the origin request policy.
Instance Attribute Details
#id ⇒ String
The unique identifier for the origin request policy. If the origin request policy is attached to a distribution’s cache behavior, you can get the policy’s identifier using ListDistributions or GetDistribution. If the origin request policy is not attached to a cache behavior, you can get the identifier using ListOriginRequestPolicies.
7772 7773 7774 7775 7776 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 7772 class GetOriginRequestPolicyConfigRequest < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |