Class: Aws::CloudFront::Types::GetTrustStoreResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::GetTrustStoreResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#etag ⇒ String
The version identifier for the current version of the trust store.
-
#trust_store ⇒ Types::TrustStore
The trust store.
Instance Attribute Details
#etag ⇒ String
The version identifier for the current version of the trust store.
8165 8166 8167 8168 8169 8170 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8165 class GetTrustStoreResult < Struct.new( :trust_store, :etag) SENSITIVE = [] include Aws::Structure end |
#trust_store ⇒ Types::TrustStore
The trust store.
8165 8166 8167 8168 8169 8170 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8165 class GetTrustStoreResult < Struct.new( :trust_store, :etag) SENSITIVE = [] include Aws::Structure end |