Class: Aws::CloudFront::Types::ImportSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The import source for the key value store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_arnString

The Amazon Resource Name (ARN) of the import source for the key value store.

Returns:

  • (String)


8306
8307
8308
8309
8310
8311
# File 'lib/aws-sdk-cloudfront/types.rb', line 8306

class ImportSource < Struct.new(
  :source_type,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The source type of the import source for the key value store.

Returns:

  • (String)


8306
8307
8308
8309
8310
8311
# File 'lib/aws-sdk-cloudfront/types.rb', line 8306

class ImportSource < Struct.new(
  :source_type,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end