Class: Aws::CloudFront::Types::InvalidationBatch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

An invalidation batch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#caller_referenceString

A value that you specify to uniquely identify an invalidation request. CloudFront uses the value to prevent you from accidentally resubmitting an identical request. Whenever you create a new invalidation request, you must specify a new value for CallerReference and change other values in the request as applicable. One way to ensure that the value of CallerReference is unique is to use a timestamp, for example, 20120301090000.

If you make a second invalidation request with the same value for CallerReference, and if the rest of the request is the same, CloudFront doesn't create a new invalidation request. Instead, CloudFront returns information about the invalidation request that you previously created with the same CallerReference.

If CallerReference is a value you already sent in a previous invalidation batch request but the content of any Path is different from the original request, CloudFront returns an InvalidationBatchAlreadyExists error.



8775
8776
8777
8778
8779
8780
# File 'lib/aws-sdk-cloudfront/types.rb', line 8775

class InvalidationBatch < Struct.new(
  :paths,
  :caller_reference)
  SENSITIVE = []
  include Aws::Structure
end

#pathsTypes::Paths

A complex type that contains information about the objects that you want to invalidate. For more information, see Specifying the Objects to Invalidate in the Amazon CloudFront Developer Guide.



8775
8776
8777
8778
8779
8780
# File 'lib/aws-sdk-cloudfront/types.rb', line 8775

class InvalidationBatch < Struct.new(
  :paths,
  :caller_reference)
  SENSITIVE = []
  include Aws::Structure
end