Class: Aws::CloudFront::Types::KeyGroupList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of key groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::KeyGroupSummary>

A list of key groups.

Returns:



9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-cloudfront/types.rb', line 9035

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of key groups requested.

Returns:



9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-cloudfront/types.rb', line 9035

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing key groups.

Returns:



9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-cloudfront/types.rb', line 9035

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of key groups returned in the response.

Returns:



9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-cloudfront/types.rb', line 9035

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end