Class: Aws::CloudFront::Types::KeyValueStore
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::KeyValueStore
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The Key Value Store. Use this to separate data from function code, allowing you to update data without having to publish a new version of a function. The Key Value Store holds keys and their corresponding values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the Key Value Store.
-
#comment ⇒ String
A comment for the Key Value Store.
-
#id ⇒ String
The unique Id for the Key Value Store.
-
#last_modified_time ⇒ Time
The last-modified time of the Key Value Store.
-
#name ⇒ String
The name of the Key Value Store.
-
#status ⇒ String
The status of the Key Value Store.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
A comment for the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique Id for the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last-modified time of the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Key Value Store.
6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6669 class KeyValueStore < Struct.new( :name, :id, :comment, :arn, :status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |