Class: Aws::CloudFront::Types::LambdaFunctionAssociations
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::LambdaFunctionAssociations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A complex type that specifies a list of Lambda@Edge functions associations for a cache behavior.
If you want to invoke one or more Lambda@Edge functions triggered by requests that match the PathPattern of the cache behavior, specify the applicable values for Quantity and Items. Note that there can be up to 4 LambdaFunctionAssociation items in this list (one for each possible value of EventType) and each EventType can be associated with only one function.
If you don’t want to invoke any Lambda@Edge functions for the requests that match PathPattern, specify 0 for Quantity and omit Items.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::LambdaFunctionAssociation>
Optional: A complex type that contains
LambdaFunctionAssociationitems for this cache behavior. -
#quantity ⇒ Integer
The number of Lambda@Edge function associations for this cache behavior.
Instance Attribute Details
#items ⇒ Array<Types::LambdaFunctionAssociation>
Optional: A complex type that contains LambdaFunctionAssociation items for this cache behavior. If Quantity is 0, you can omit Items.
9231 9232 9233 9234 9235 9236 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9231 class LambdaFunctionAssociations < Struct.new( :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of Lambda@Edge function associations for this cache behavior.
9231 9232 9233 9234 9235 9236 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9231 class LambdaFunctionAssociations < Struct.new( :quantity, :items) SENSITIVE = [] include Aws::Structure end |