Class: Aws::CloudFront::Types::ListAnycastIpListsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


9253
9254
9255
9256
9257
9258
# File 'lib/aws-sdk-cloudfront/types.rb', line 9253

class ListAnycastIpListsRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of Anycast static IP lists that you want returned in the response.

Returns:

  • (Integer)


9253
9254
9255
9256
9257
9258
# File 'lib/aws-sdk-cloudfront/types.rb', line 9253

class ListAnycastIpListsRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end