Class: Aws::CloudFront::Types::ListConflictingAliasesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The alias (also called a CNAME) to search for conflicting aliases.

Returns:

  • (String)


9440
9441
9442
9443
9444
9445
9446
9447
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConflictingAliasesRequest < Struct.new(
  :distribution_id,
  :alias,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_idString

The ID of a standard distribution in your account that has an attached TLS certificate that includes the provided alias.

Returns:

  • (String)


9440
9441
9442
9443
9444
9445
9446
9447
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConflictingAliasesRequest < Struct.new(
  :distribution_id,
  :alias,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in the list of conflicting aliases. The response includes conflicting aliases in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Returns:

  • (String)


9440
9441
9442
9443
9444
9445
9446
9447
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConflictingAliasesRequest < Struct.new(
  :distribution_id,
  :alias,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of conflicting aliases that you want in the response.

Returns:

  • (Integer)


9440
9441
9442
9443
9444
9445
9446
9447
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConflictingAliasesRequest < Struct.new(
  :distribution_id,
  :alias,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end