Class: Aws::CloudFront::Types::ListConnectionFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListConnectionFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list.
-
#max_items ⇒ Integer
The maximum number of connection functions that you want returned in the response.
-
#stage ⇒ String
The connection function's stage.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list. The response includes items in the list that occur after
the marker. To get the next page of the list, set this field's
value to the value of NextMarker from the current page's
response.
9480 9481 9482 9483 9484 9485 9486 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9480 class ListConnectionFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of connection functions that you want returned in the response.
9480 9481 9482 9483 9484 9485 9486 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9480 class ListConnectionFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |
#stage ⇒ String
The connection function's stage.
9480 9481 9482 9483 9484 9485 9486 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9480 class ListConnectionFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |