Class: Aws::CloudFront::Types::ListConnectionFunctionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListConnectionFunctionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_functions ⇒ Array<Types::ConnectionFunctionSummary>
A list of connection functions.
-
#next_marker ⇒ String
Indicates the next page of connection functions.
Instance Attribute Details
#connection_functions ⇒ Array<Types::ConnectionFunctionSummary>
A list of connection functions.
9434 9435 9436 9437 9438 9439 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9434 class ListConnectionFunctionsResult < Struct.new( :next_marker, :connection_functions) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
Indicates the next page of connection functions. To get the next page of the list, use this value in the Marker field of your request.
9434 9435 9436 9437 9438 9439 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9434 class ListConnectionFunctionsResult < Struct.new( :next_marker, :connection_functions) SENSITIVE = [] include Aws::Structure end |