Class: Aws::CloudFront::Types::ListConnectionGroupsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_groupsArray<Types::ConnectionGroupSummary>

The list of connection groups that you retrieved.



9541
9542
9543
9544
9545
9546
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541

class ListConnectionGroupsResult < Struct.new(
  :next_marker,
  :connection_groups)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.



9541
9542
9543
9544
9545
9546
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541

class ListConnectionGroupsResult < Struct.new(
  :next_marker,
  :connection_groups)
  SENSITIVE = []
  include Aws::Structure
end