Class: Aws::CloudFront::Types::ListContinuousDeploymentPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of continuous deployment policies. The response includes policies in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Returns:

  • (String)


9563
9564
9565
9566
9567
9568
# File 'lib/aws-sdk-cloudfront/types.rb', line 9563

class ListContinuousDeploymentPoliciesRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of continuous deployment policies that you want returned in the response.

Returns:

  • (Integer)


9563
9564
9565
9566
9567
9568
# File 'lib/aws-sdk-cloudfront/types.rb', line 9563

class ListContinuousDeploymentPoliciesRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end