Class: Aws::CloudFront::Types::ListDistributionTenantsByCustomizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionTenantsByCustomizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
Filter by the ARN of the associated ACM certificate.
-
#marker ⇒ String
The marker for the next set of results.
-
#max_items ⇒ Integer
The maximum number of distribution tenants to return by the specified customization.
-
#web_acl_arn ⇒ String
Filter by the ARN of the associated WAF web ACL.
Instance Attribute Details
#certificate_arn ⇒ String
Filter by the ARN of the associated ACM certificate.
9541 9542 9543 9544 9545 9546 9547 9548 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541 class ListDistributionTenantsByCustomizationRequest < Struct.new( :web_acl_arn, :certificate_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The marker for the next set of results.
9541 9542 9543 9544 9545 9546 9547 9548 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541 class ListDistributionTenantsByCustomizationRequest < Struct.new( :web_acl_arn, :certificate_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution tenants to return by the specified customization.
9541 9542 9543 9544 9545 9546 9547 9548 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541 class ListDistributionTenantsByCustomizationRequest < Struct.new( :web_acl_arn, :certificate_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#web_acl_arn ⇒ String
Filter by the ARN of the associated WAF web ACL.
9541 9542 9543 9544 9545 9546 9547 9548 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9541 class ListDistributionTenantsByCustomizationRequest < Struct.new( :web_acl_arn, :certificate_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |