Class: Aws::CloudFront::Types::ListDistributionTenantsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionTenantsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution_tenant_list ⇒ Array<Types::DistributionTenantSummary>
The list of distribution tenants that you retrieved.
-
#next_marker ⇒ String
A token used for pagination of results returned in the response.
Instance Attribute Details
#distribution_tenant_list ⇒ Array<Types::DistributionTenantSummary>
The list of distribution tenants that you retrieved.
9603 9604 9605 9606 9607 9608 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9603 class ListDistributionTenantsResult < Struct.new( :next_marker, :distribution_tenant_list) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.
9603 9604 9605 9606 9607 9608 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9603 class ListDistributionTenantsResult < Struct.new( :next_marker, :distribution_tenant_list) SENSITIVE = [] include Aws::Structure end |