Class: Aws::CloudFront::Types::ListDistributionsByAnycastIpListIdRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anycast_ip_list_idString

The ID of the Anycast static IP list.

Returns:

  • (String)


9629
9630
9631
9632
9633
9634
9635
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629

class ListDistributionsByAnycastIpListIdRequest < Struct.new(
  :marker,
  :max_items,
  :anycast_ip_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


9629
9630
9631
9632
9633
9634
9635
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629

class ListDistributionsByAnycastIpListIdRequest < Struct.new(
  :marker,
  :max_items,
  :anycast_ip_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distributions that you want returned in the response.

Returns:

  • (Integer)


9629
9630
9631
9632
9633
9634
9635
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629

class ListDistributionsByAnycastIpListIdRequest < Struct.new(
  :marker,
  :max_items,
  :anycast_ip_list_id)
  SENSITIVE = []
  include Aws::Structure
end