Class: Aws::CloudFront::Types::ListDistributionsByCachePolicyIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByCachePolicyIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_policy_id ⇒ String
The ID of the cache policy whose associated distribution IDs you want to list.
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs.
-
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
Instance Attribute Details
#cache_policy_id ⇒ String
The ID of the cache policy whose associated distribution IDs you want to list.
9729 9730 9731 9732 9733 9734 9735 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9729 class ListDistributionsByCachePolicyIdRequest < Struct.new( :marker, :max_items, :cache_policy_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of distribution IDs. The response includes distribution
IDs in the list that occur after the marker. To get the next page of
the list, set this field's value to the value of NextMarker from
the current page's response.
9729 9730 9731 9732 9733 9734 9735 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9729 class ListDistributionsByCachePolicyIdRequest < Struct.new( :marker, :max_items, :cache_policy_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
9729 9730 9731 9732 9733 9734 9735 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9729 class ListDistributionsByCachePolicyIdRequest < Struct.new( :marker, :max_items, :cache_policy_id) SENSITIVE = [] include Aws::Structure end |