Class: Aws::CloudFront::Types::ListDistributionsByKeyGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_group_idString

The ID of the key group whose associated distribution IDs you are listing.



9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-cloudfront/types.rb', line 9844

class ListDistributionsByKeyGroupRequest < Struct.new(
  :marker,
  :max_items,
  :key_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in your list of distribution IDs. The response includes distribution IDs in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.



9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-cloudfront/types.rb', line 9844

class ListDistributionsByKeyGroupRequest < Struct.new(
  :marker,
  :max_items,
  :key_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distribution IDs that you want in the response.



9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-cloudfront/types.rb', line 9844

class ListDistributionsByKeyGroupRequest < Struct.new(
  :marker,
  :max_items,
  :key_group_id)
  SENSITIVE = []
  include Aws::Structure
end