Class: Aws::CloudFront::Types::ListDistributionsByOwnedResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of distributions. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Returns:

  • (String)


9923
9924
9925
9926
9927
9928
9929
# File 'lib/aws-sdk-cloudfront/types.rb', line 9923

class ListDistributionsByOwnedResourceRequest < Struct.new(
  :resource_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distributions to return.

Returns:

  • (Integer)


9923
9924
9925
9926
9927
9928
9929
# File 'lib/aws-sdk-cloudfront/types.rb', line 9923

class ListDistributionsByOwnedResourceRequest < Struct.new(
  :resource_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of the CloudFront resource that you've shared with other Amazon Web Services accounts.

Returns:

  • (String)


9923
9924
9925
9926
9927
9928
9929
# File 'lib/aws-sdk-cloudfront/types.rb', line 9923

class ListDistributionsByOwnedResourceRequest < Struct.new(
  :resource_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end