Class: Aws::CloudFront::Types::ListDistributionsByOwnedResourceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByOwnedResourceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution_list ⇒ Types::DistributionIdOwnerList
The list of distributions that are using the shared resource.
Instance Attribute Details
#distribution_list ⇒ Types::DistributionIdOwnerList
The list of distributions that are using the shared resource.
9877 9878 9879 9880 9881 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9877 class ListDistributionsByOwnedResourceResult < Struct.new( :distribution_list) SENSITIVE = [] include Aws::Structure end |