Class: Aws::CloudFront::Types::ListDistributionsByRealtimeLogConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of distributions. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Returns:

  • (String)


9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-cloudfront/types.rb', line 9967

class ListDistributionsByRealtimeLogConfigRequest < Struct.new(
  :marker,
  :max_items,
  :realtime_log_config_name,
  :realtime_log_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distributions that you want in the response.

Returns:

  • (Integer)


9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-cloudfront/types.rb', line 9967

class ListDistributionsByRealtimeLogConfigRequest < Struct.new(
  :marker,
  :max_items,
  :realtime_log_config_name,
  :realtime_log_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#realtime_log_config_arnString

The Amazon Resource Name (ARN) of the real-time log configuration whose associated distributions you want to list.

Returns:

  • (String)


9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-cloudfront/types.rb', line 9967

class ListDistributionsByRealtimeLogConfigRequest < Struct.new(
  :marker,
  :max_items,
  :realtime_log_config_name,
  :realtime_log_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#realtime_log_config_nameString

The name of the real-time log configuration whose associated distributions you want to list.

Returns:

  • (String)


9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-cloudfront/types.rb', line 9967

class ListDistributionsByRealtimeLogConfigRequest < Struct.new(
  :marker,
  :max_items,
  :realtime_log_config_name,
  :realtime_log_config_arn)
  SENSITIVE = []
  include Aws::Structure
end