Class: Aws::CloudFront::Types::ListDistributionsByTrustStoreRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of ‘NextMarker` from the current page’s response.

Returns:

  • (String)


9981
9982
9983
9984
9985
9986
9987
# File 'lib/aws-sdk-cloudfront/types.rb', line 9981

class ListDistributionsByTrustStoreRequest < Struct.new(
  :trust_store_identifier,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distributions that you want returned in the response.

Returns:

  • (Integer)


9981
9982
9983
9984
9985
9986
9987
# File 'lib/aws-sdk-cloudfront/types.rb', line 9981

class ListDistributionsByTrustStoreRequest < Struct.new(
  :trust_store_identifier,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#trust_store_identifierString

The distributions by trust store identifier.

Returns:

  • (String)


9981
9982
9983
9984
9985
9986
9987
# File 'lib/aws-sdk-cloudfront/types.rb', line 9981

class ListDistributionsByTrustStoreRequest < Struct.new(
  :trust_store_identifier,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end