Class: Aws::CloudFront::Types::ListDistributionsByVpcOriginIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByVpcOriginIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
The marker associated with the VPC origin distributions list.
-
#max_items ⇒ Integer
The maximum number of items included in the list.
-
#vpc_origin_id ⇒ String
The VPC origin ID.
Instance Attribute Details
#marker ⇒ String
The marker associated with the VPC origin distributions list.
10021 10022 10023 10024 10025 10026 10027 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10021 class ListDistributionsByVpcOriginIdRequest < Struct.new( :marker, :max_items, :vpc_origin_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of items included in the list.
10021 10022 10023 10024 10025 10026 10027 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10021 class ListDistributionsByVpcOriginIdRequest < Struct.new( :marker, :max_items, :vpc_origin_id) SENSITIVE = [] include Aws::Structure end |
#vpc_origin_id ⇒ String
The VPC origin ID.
10021 10022 10023 10024 10025 10026 10027 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10021 class ListDistributionsByVpcOriginIdRequest < Struct.new( :marker, :max_items, :vpc_origin_id) SENSITIVE = [] include Aws::Structure end |