Class: Aws::CloudFront::Types::ListFieldLevelEncryptionConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListFieldLevelEncryptionConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of configurations.
-
#max_items ⇒ Integer
The maximum number of field-level encryption configurations you want in the response body.
Instance Attribute Details
#marker ⇒ String
Use this when paginating results to indicate where to begin in your
list of configurations. The results include configurations in the
list that occur after the marker. To get the next page of results,
set the Marker to the value of the NextMarker from the current
page's response (which is also the ID of the last configuration on
that page).
10259 10260 10261 10262 10263 10264 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10259 class ListFieldLevelEncryptionConfigsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of field-level encryption configurations you want in the response body.
10259 10260 10261 10262 10263 10264 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10259 class ListFieldLevelEncryptionConfigsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |