Class: Aws::CloudFront::Types::ListFieldLevelEncryptionProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListFieldLevelEncryptionProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of profiles.
-
#max_items ⇒ Integer
The maximum number of field-level encryption profiles you want in the response body.
Instance Attribute Details
#marker ⇒ String
Use this when paginating results to indicate where to begin in your
list of profiles. The results include profiles in the list that
occur after the marker. To get the next page of results, set the
Marker to the value of the NextMarker from the current page's
response (which is also the ID of the last profile on that page).
10294 10295 10296 10297 10298 10299 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10294 class ListFieldLevelEncryptionProfilesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of field-level encryption profiles you want in the response body.
10294 10295 10296 10297 10298 10299 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10294 class ListFieldLevelEncryptionProfilesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |