Class: Aws::CloudFront::Types::ListFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of functions.
-
#max_items ⇒ Integer
The maximum number of functions that you want in the response.
-
#stage ⇒ String
An optional filter to return only the functions that are in the specified stage, either
DEVELOPMENTorLIVE.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of functions. The response includes functions in the list
that occur after the marker. To get the next page of the list, set
this field's value to the value of NextMarker from the current
page's response.
10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10333 class ListFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of functions that you want in the response.
10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10333 class ListFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |
#stage ⇒ String
An optional filter to return only the functions that are in the
specified stage, either DEVELOPMENT or LIVE.
10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10333 class ListFunctionsRequest < Struct.new( :marker, :max_items, :stage) SENSITIVE = [] include Aws::Structure end |