Class: Aws::CloudFront::Types::ListInvalidationsForDistributionTenantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListInvalidationsForDistributionTenantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the distribution tenant.
-
#marker ⇒ String
Use this parameter when paginating results to indicate where to begin in your list of invalidation batches.
-
#max_items ⇒ Integer
The maximum number of invalidations to return for the distribution tenant.
Instance Attribute Details
#id ⇒ String
The ID of the distribution tenant.
10315 10316 10317 10318 10319 10320 10321 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10315 class ListInvalidationsForDistributionTenantRequest < Struct.new( :id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter when paginating results to indicate where to begin in your list of invalidation batches. Because the results are returned in decreasing order from most recent to oldest, the most recent results are on the first page, the second page will contain earlier results, and so on. To get the next page of results, set Marker to the value of the NextMarker from the current page’s response. This value is the same as the ID of the last invalidation batch on that page.
10315 10316 10317 10318 10319 10320 10321 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10315 class ListInvalidationsForDistributionTenantRequest < Struct.new( :id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of invalidations to return for the distribution tenant.
10315 10316 10317 10318 10319 10320 10321 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10315 class ListInvalidationsForDistributionTenantRequest < Struct.new( :id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |