Class: Aws::CloudFront::Types::ListKeyGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of key groups. The response includes key groups in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-cloudfront/types.rb', line 10402

class ListKeyGroupsRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of key groups that you want in the response.

Returns:

  • (Integer)


10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-cloudfront/types.rb', line 10402

class ListKeyGroupsRequest < Struct.new(
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end