Class: Aws::CloudFront::Types::ListOriginAccessControlsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListOriginAccessControlsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of origin access controls.
-
#max_items ⇒ Integer
The maximum number of origin access controls that you want in the response.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of origin access controls. The response includes the items
in the list that occur after the marker. To get the next page of the
list, set this field's value to the value of NextMarker from the
current page's response.
10530 10531 10532 10533 10534 10535 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10530 class ListOriginAccessControlsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin access controls that you want in the response.
10530 10531 10532 10533 10534 10535 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10530 class ListOriginAccessControlsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |