Class: Aws::CloudFront::Types::ListOriginRequestPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListOriginRequestPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of origin request policies.
-
#max_items ⇒ Integer
The maximum number of origin request policies that you want in the response.
-
#type ⇒ String
A filter to return only the specified kinds of origin request policies.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of origin request policies. The response includes origin request policies in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
10515 10516 10517 10518 10519 10520 10521 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10515 class ListOriginRequestPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin request policies that you want in the response.
10515 10516 10517 10518 10519 10520 10521 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10515 class ListOriginRequestPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
A filter to return only the specified kinds of origin request policies. Valid values are:
-
managed– Returns only the managed policies created by Amazon Web Services. -
custom– Returns only the custom policies created in your Amazon Web Services account.
10515 10516 10517 10518 10519 10520 10521 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10515 class ListOriginRequestPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |