Class: Aws::CloudFront::Types::ListResponseHeadersPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListResponseHeadersPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of response headers policies.
-
#max_items ⇒ Integer
The maximum number of response headers policies that you want to get in the response.
-
#type ⇒ String
A filter to get only the specified kind of response headers policies.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of response headers policies. The response includes
response headers policies in the list that occur after the marker.
To get the next page of the list, set this field's value to the
value of NextMarker from the current page's response.
10690 10691 10692 10693 10694 10695 10696 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10690 class ListResponseHeadersPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of response headers policies that you want to get in the response.
10690 10691 10692 10693 10694 10695 10696 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10690 class ListResponseHeadersPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
A filter to get only the specified kind of response headers policies. Valid values are:
-
managed– Gets only the managed policies created by Amazon Web Services. -
custom– Gets only the custom policies created in your Amazon Web Services account.
10690 10691 10692 10693 10694 10695 10696 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10690 class ListResponseHeadersPoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |