Class: Aws::CloudFront::Types::ListTrustStoresResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

Indicates the next page of trust stores. To get the next page of the list, use this value in the Marker field of your request.

Returns:

  • (String)


10738
10739
10740
10741
10742
10743
# File 'lib/aws-sdk-cloudfront/types.rb', line 10738

class ListTrustStoresResult < Struct.new(
  :next_marker,
  :trust_store_list)
  SENSITIVE = []
  include Aws::Structure
end

#trust_store_listArray<Types::TrustStoreSummary>

The trust store list.

Returns:



10738
10739
10740
10741
10742
10743
# File 'lib/aws-sdk-cloudfront/types.rb', line 10738

class ListTrustStoresResult < Struct.new(
  :next_marker,
  :trust_store_list)
  SENSITIVE = []
  include Aws::Structure
end