Class: Aws::CloudFront::Types::ListVpcOriginsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListVpcOriginsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
The marker associated with the VPC origins list.
-
#max_items ⇒ Integer
The maximum number of items included in the list.
Instance Attribute Details
#marker ⇒ String
The marker associated with the VPC origins list.
10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10755 class ListVpcOriginsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of items included in the list.
10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10755 class ListVpcOriginsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |