Class: Aws::CloudFront::Types::OriginAccessControlList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of CloudFront origin access controls.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

If there are more items in the list than are in this response, this value is true.

Returns:

  • (Boolean)


11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::OriginAccessControlSummary>

Contains the origin access controls in the list.



11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The value of the Marker field that was provided in the request.

Returns:

  • (String)


11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of origin access controls requested.

Returns:

  • (Integer)


11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value to use in the Marker field of another request to continue listing origin access controls.

Returns:

  • (String)


11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of origin access controls returned in the response.

Returns:

  • (Integer)


11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542

class OriginAccessControlList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end