Class: Aws::CloudFront::Types::OriginAccessControlSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A CloudFront origin access control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the origin access control.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the origin access control.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name that identifies the origin access control.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end

#origin_access_control_origin_typeString

The type of origin that this origin access control is for.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end

#signing_behaviorString

A value that specifies which requests CloudFront signs (adds authentication information to). This field can have one of the following values:

  • never – CloudFront doesn’t sign any origin requests.

  • always – CloudFront signs all origin requests, overwriting the Authorization header from the viewer request if necessary.

  • no-override – If the viewer request doesn’t contain the Authorization header, CloudFront signs the origin request. If the viewer request contains the Authorization header, CloudFront doesn’t sign the origin request, but instead passes along the Authorization header that it received in the viewer request.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end

#signing_protocolString

The signing protocol of the origin access control. The signing protocol determines how CloudFront signs (authenticates) requests. The only valid value is sigv4.

Returns:

  • (String)


8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464

class OriginAccessControlSummary < Struct.new(
  :id,
  :description,
  :name,
  :signing_protocol,
  :signing_behavior,
  :origin_access_control_origin_type)
  SENSITIVE = []
  include Aws::Structure
end