Class: Aws::CloudFront::Types::OriginGroupFailoverCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginGroupFailoverCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A complex data type that includes information about the failover criteria for an origin group, including the status codes for which CloudFront will failover from the primary origin to the second origin.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status_codes ⇒ Types::StatusCodes
The status codes that, when returned from the primary origin, will trigger CloudFront to failover to the second origin.
Instance Attribute Details
#status_codes ⇒ Types::StatusCodes
The status codes that, when returned from the primary origin, will trigger CloudFront to failover to the second origin.
11736 11737 11738 11739 11740 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11736 class OriginGroupFailoverCriteria < Struct.new( :status_codes) SENSITIVE = [] include Aws::Structure end |