Class: Aws::CloudFront::Types::OriginRequestPolicyCookiesConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

An object that determines whether any cookies in viewer requests (and if so, which cookies) are included in requests that CloudFront sends to the origin.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Determines whether cookies in viewer requests are included in requests that CloudFront sends to the origin. Valid values are:

  • none – No cookies in viewer requests are included in requests that CloudFront sends to the origin. Even when this field is set to none, any cookies that are listed in a CachePolicy are included in origin requests.

  • whitelist – Only the cookies in viewer requests that are listed in the CookieNames type are included in requests that CloudFront sends to the origin.

  • all – All cookies in viewer requests are included in requests that CloudFront sends to the origin.

  • allExcept – All cookies in viewer requests are included in requests that CloudFront sends to the origin, except for those listed in the CookieNames type, which are not included.



11976
11977
11978
11979
11980
11981
# File 'lib/aws-sdk-cloudfront/types.rb', line 11976

class OriginRequestPolicyCookiesConfig < Struct.new(
  :cookie_behavior,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#cookiesTypes::CookieNames

Contains a list of cookie names.



11976
11977
11978
11979
11980
11981
# File 'lib/aws-sdk-cloudfront/types.rb', line 11976

class OriginRequestPolicyCookiesConfig < Struct.new(
  :cookie_behavior,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end