Class: Aws::CloudFront::Types::OriginShield
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginShield
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
CloudFront Origin Shield.
Using Origin Shield can help reduce the load on your origin. For more information, see [Using Origin Shield] in the *Amazon CloudFront Developer Guide*.
[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
A flag that specifies whether Origin Shield is enabled.
-
#origin_shield_region ⇒ String
The Amazon Web Services Region for Origin Shield.
Instance Attribute Details
#enabled ⇒ Boolean
A flag that specifies whether Origin Shield is enabled.
When it’s enabled, CloudFront routes all requests through Origin Shield, which can help protect your origin. When it’s disabled, CloudFront might send requests directly to your origin from multiple edge locations or regional edge caches.
12176 12177 12178 12179 12180 12181 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12176 class OriginShield < Struct.new( :enabled, :origin_shield_region) SENSITIVE = [] include Aws::Structure end |
#origin_shield_region ⇒ String
The Amazon Web Services Region for Origin Shield.
Specify the Amazon Web Services Region that has the lowest latency to your origin. To specify a region, use the region code, not the region name. For example, specify the US East (Ohio) region as ‘us-east-2`.
When you enable CloudFront Origin Shield, you must specify the Amazon Web Services Region for Origin Shield. For the list of Amazon Web Services Regions that you can specify, and for help choosing the best Region for your origin, see [Choosing the Amazon Web Services Region for Origin Shield] in the *Amazon CloudFront Developer Guide*.
12176 12177 12178 12179 12180 12181 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12176 class OriginShield < Struct.new( :enabled, :origin_shield_region) SENSITIVE = [] include Aws::Structure end |