Class: Aws::CloudFront::Types::Parameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of parameter values to add to the resource. A parameter is specified as a key-value pair. A valid parameter value must exist for any parameter that is marked as required in the multi-tenant distribution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The parameter name.

Returns:

  • (String)


12230
12231
12232
12233
12234
12235
# File 'lib/aws-sdk-cloudfront/types.rb', line 12230

class Parameter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The parameter value.

Returns:

  • (String)


12230
12231
12232
12233
12234
12235
# File 'lib/aws-sdk-cloudfront/types.rb', line 12230

class Parameter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end