Class: Aws::CloudFront::Types::Paths
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::Paths
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A complex type that contains information about the objects that you want to invalidate. For more information, see Specifying the Objects to Invalidate in the Amazon CloudFront Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<String>
A complex type that contains a list of the paths that you want to invalidate.
-
#quantity ⇒ Integer
The number of invalidation paths specified for the objects that you want to invalidate.