Class: Aws::CloudFront::Types::RealtimeLogConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::RealtimeLogConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A real-time log configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of this real-time log configuration.
-
#end_points ⇒ Array<Types::EndPoint>
Contains information about the Amazon Kinesis data stream where you are sending real-time log data for this real-time log configuration.
-
#fields ⇒ Array<String>
A list of fields that are included in each real-time log record.
-
#name ⇒ String
The unique name of this real-time log configuration.
-
#sampling_rate ⇒ Integer
The sampling rate for this real-time log configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of this real-time log configuration.
12890 12891 12892 12893 12894 12895 12896 12897 12898 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12890 class RealtimeLogConfig < Struct.new( :arn, :name, :sampling_rate, :end_points, :fields) SENSITIVE = [] include Aws::Structure end |
#end_points ⇒ Array<Types::EndPoint>
Contains information about the Amazon Kinesis data stream where you are sending real-time log data for this real-time log configuration.
12890 12891 12892 12893 12894 12895 12896 12897 12898 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12890 class RealtimeLogConfig < Struct.new( :arn, :name, :sampling_rate, :end_points, :fields) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<String>
A list of fields that are included in each real-time log record. In an API response, the fields are provided in the same order in which they are sent to the Amazon Kinesis data stream.
For more information about fields, see [Real-time log configuration fields] in the *Amazon CloudFront Developer Guide*.
12890 12891 12892 12893 12894 12895 12896 12897 12898 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12890 class RealtimeLogConfig < Struct.new( :arn, :name, :sampling_rate, :end_points, :fields) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name of this real-time log configuration.
12890 12891 12892 12893 12894 12895 12896 12897 12898 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12890 class RealtimeLogConfig < Struct.new( :arn, :name, :sampling_rate, :end_points, :fields) SENSITIVE = [] include Aws::Structure end |
#sampling_rate ⇒ Integer
The sampling rate for this real-time log configuration. The sampling rate determines the percentage of viewer requests that are represented in the real-time log data. The sampling rate is an integer between 1 and 100, inclusive.
12890 12891 12892 12893 12894 12895 12896 12897 12898 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12890 class RealtimeLogConfig < Struct.new( :arn, :name, :sampling_rate, :end_points, :fields) SENSITIVE = [] include Aws::Structure end |