Class: Aws::CloudFront::Types::ResponseHeadersPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ResponseHeadersPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A response headers policy.
A response headers policy contains information about a set of HTTP response headers.
After you create a response headers policy, you can use its ID to attach it to one or more cache behaviors in a CloudFront distribution. When it’s attached to a cache behavior, the response headers policy affects the HTTP headers that CloudFront includes in HTTP responses to requests that match the cache behavior. CloudFront adds or removes response headers according to the configuration of the response headers policy.
For more information, see [Adding or removing HTTP headers in CloudFront responses] in the *Amazon CloudFront Developer Guide*.
[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/modifying-response-headers.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier for the response headers policy.
-
#last_modified_time ⇒ Time
The date and time when the response headers policy was last modified.
-
#response_headers_policy_config ⇒ Types::ResponseHeadersPolicyConfig
A response headers policy configuration.
Instance Attribute Details
#id ⇒ String
The identifier for the response headers policy.
13059 13060 13061 13062 13063 13064 13065 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13059 class ResponseHeadersPolicy < Struct.new( :id, :last_modified_time, :response_headers_policy_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time when the response headers policy was last modified.
13059 13060 13061 13062 13063 13064 13065 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13059 class ResponseHeadersPolicy < Struct.new( :id, :last_modified_time, :response_headers_policy_config) SENSITIVE = [] include Aws::Structure end |
#response_headers_policy_config ⇒ Types::ResponseHeadersPolicyConfig
A response headers policy configuration.
13059 13060 13061 13062 13063 13064 13065 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13059 class ResponseHeadersPolicy < Struct.new( :id, :last_modified_time, :response_headers_policy_config) SENSITIVE = [] include Aws::Structure end |