Class: Aws::CloudFront::Types::ResponseHeadersPolicyCorsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ResponseHeadersPolicyCorsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS). CloudFront adds these headers to HTTP responses that it sends for CORS requests that match a cache behavior associated with this response headers policy.
For more information about CORS, see [Cross-Origin Resource Sharing (CORS)] in the MDN Web Docs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_control_allow_credentials ⇒ Boolean
A Boolean that CloudFront uses as the value for the
Access-Control-Allow-CredentialsHTTP response header. -
#access_control_allow_headers ⇒ Types::ResponseHeadersPolicyAccessControlAllowHeaders
A list of HTTP header names that CloudFront includes as values for the
Access-Control-Allow-HeadersHTTP response header. -
#access_control_allow_methods ⇒ Types::ResponseHeadersPolicyAccessControlAllowMethods
A list of HTTP methods that CloudFront includes as values for the
Access-Control-Allow-MethodsHTTP response header. -
#access_control_allow_origins ⇒ Types::ResponseHeadersPolicyAccessControlAllowOrigins
A list of origins (domain names) that CloudFront can use as the value for the
Access-Control-Allow-OriginHTTP response header. -
#access_control_expose_headers ⇒ Types::ResponseHeadersPolicyAccessControlExposeHeaders
A list of HTTP headers that CloudFront includes as values for the
Access-Control-Expose-HeadersHTTP response header. -
#access_control_max_age_sec ⇒ Integer
A number that CloudFront uses as the value for the
Access-Control-Max-AgeHTTP response header. -
#origin_override ⇒ Boolean
A Boolean that determines whether CloudFront overrides HTTP response headers received from the origin with the ones specified in this response headers policy.
Instance Attribute Details
#access_control_allow_credentials ⇒ Boolean
A Boolean that CloudFront uses as the value for the Access-Control-Allow-Credentials HTTP response header.
For more information about the Access-Control-Allow-Credentials HTTP response header, see [Access-Control-Allow-Credentials] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#access_control_allow_headers ⇒ Types::ResponseHeadersPolicyAccessControlAllowHeaders
A list of HTTP header names that CloudFront includes as values for the Access-Control-Allow-Headers HTTP response header.
For more information about the Access-Control-Allow-Headers HTTP response header, see [Access-Control-Allow-Headers] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#access_control_allow_methods ⇒ Types::ResponseHeadersPolicyAccessControlAllowMethods
A list of HTTP methods that CloudFront includes as values for the Access-Control-Allow-Methods HTTP response header.
For more information about the Access-Control-Allow-Methods HTTP response header, see [Access-Control-Allow-Methods] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#access_control_allow_origins ⇒ Types::ResponseHeadersPolicyAccessControlAllowOrigins
A list of origins (domain names) that CloudFront can use as the value for the Access-Control-Allow-Origin HTTP response header.
For more information about the Access-Control-Allow-Origin HTTP response header, see [Access-Control-Allow-Origin] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#access_control_expose_headers ⇒ Types::ResponseHeadersPolicyAccessControlExposeHeaders
A list of HTTP headers that CloudFront includes as values for the Access-Control-Expose-Headers HTTP response header.
For more information about the Access-Control-Expose-Headers HTTP response header, see [Access-Control-Expose-Headers] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#access_control_max_age_sec ⇒ Integer
A number that CloudFront uses as the value for the Access-Control-Max-Age HTTP response header.
For more information about the Access-Control-Max-Age HTTP response header, see [Access-Control-Max-Age] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Max-Age
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |
#origin_override ⇒ Boolean
A Boolean that determines whether CloudFront overrides HTTP response headers received from the origin with the ones specified in this response headers policy.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13346 class ResponseHeadersPolicyCorsConfig < Struct.new( :access_control_allow_origins, :access_control_allow_headers, :access_control_allow_methods, :access_control_allow_credentials, :access_control_expose_headers, :access_control_max_age_sec, :origin_override) SENSITIVE = [] include Aws::Structure end |