Class: Aws::CloudFront::Types::ResponseHeadersPolicyList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of response headers policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::ResponseHeadersPolicySummary>

The response headers policies in the list.



13565
13566
13567
13568
13569
13570
13571
13572
# File 'lib/aws-sdk-cloudfront/types.rb', line 13565

class ResponseHeadersPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of response headers policies requested.

Returns:

  • (Integer)


13565
13566
13567
13568
13569
13570
13571
13572
# File 'lib/aws-sdk-cloudfront/types.rb', line 13565

class ResponseHeadersPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing response headers policies where you left off.

Returns:

  • (String)


13565
13566
13567
13568
13569
13570
13571
13572
# File 'lib/aws-sdk-cloudfront/types.rb', line 13565

class ResponseHeadersPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of response headers policies returned.

Returns:

  • (Integer)


13565
13566
13567
13568
13569
13570
13571
13572
# File 'lib/aws-sdk-cloudfront/types.rb', line 13565

class ResponseHeadersPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end