Class: Aws::CloudFront::Types::ResponseHeadersPolicyReferrerPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ResponseHeadersPolicyReferrerPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Determines whether CloudFront includes the Referrer-Policy HTTP response header and the header’s value.
For more information about the Referrer-Policy HTTP response header, see [Referrer-Policy] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#override ⇒ Boolean
A Boolean that determines whether CloudFront overrides the
Referrer-PolicyHTTP response header received from the origin with the one specified in this response headers policy. -
#referrer_policy ⇒ String
The value of the
Referrer-PolicyHTTP response header.
Instance Attribute Details
#override ⇒ Boolean
A Boolean that determines whether CloudFront overrides the Referrer-Policy HTTP response header received from the origin with the one specified in this response headers policy.
13560 13561 13562 13563 13564 13565 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13560 class ResponseHeadersPolicyReferrerPolicy < Struct.new( :override, :referrer_policy) SENSITIVE = [] include Aws::Structure end |
#referrer_policy ⇒ String
The value of the Referrer-Policy HTTP response header. Valid values are:
-
no-referrer -
no-referrer-when-downgrade -
origin -
origin-when-cross-origin -
same-origin -
strict-origin -
strict-origin-when-cross-origin -
unsafe-url
For more information about these values, see [Referrer-Policy] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy
13560 13561 13562 13563 13564 13565 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13560 class ResponseHeadersPolicyReferrerPolicy < Struct.new( :override, :referrer_policy) SENSITIVE = [] include Aws::Structure end |