Class: Aws::CloudFront::Types::S3OriginConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A complex type that contains information about the Amazon S3 origin. If the origin is a custom origin or an S3 bucket that is configured as a website endpoint, use the CustomOriginConfig element instead.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#origin_access_identityString

<note markdown=“1”> If you’re using origin access control (OAC) instead of origin access identity, specify an empty OriginAccessIdentity element. For more information, see [Restricting access to an Amazon Web Services] in the *Amazon CloudFront Developer Guide*.

</note>

The CloudFront origin access identity to associate with the origin.

Use an origin access identity to configure the origin so that viewers can only access objects in an Amazon S3 bucket through CloudFront. The format of the value is:

`origin-access-identity/cloudfront/ID-of-origin-access-identity`

The ` ID-of-origin-access-identity ` is the value that CloudFront

returned in the ID element when you created the origin access identity.

If you want viewers to be able to access objects using either the

CloudFront URL or the Amazon S3 URL, specify an empty OriginAccessIdentity element.

To delete the origin access identity from an existing distribution,

update the distribution configuration and include an empty OriginAccessIdentity element.

To replace the origin access identity, update the distribution

configuration and specify the new origin access identity.

For more information about the origin access identity, see [Serving

Private Content through CloudFront] in the *Amazon CloudFront Developer Guide*.

[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-origin.html [2]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html

Returns:

  • (String)


13999
14000
14001
14002
14003
14004
# File 'lib/aws-sdk-cloudfront/types.rb', line 13999

class S3OriginConfig < Struct.new(
  :origin_access_identity,
  :origin_read_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#origin_read_timeoutInteger

Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the *origin response timeout*. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don’t specify otherwise) is 30 seconds.

For more information, see [Response timeout] in the *Amazon CloudFront Developer Guide*.

[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/DownloadDistValuesOrigin.html#DownloadDistValuesOriginResponseTimeout

Returns:

  • (Integer)


13999
14000
14001
14002
14003
14004
# File 'lib/aws-sdk-cloudfront/types.rb', line 13999

class S3OriginConfig < Struct.new(
  :origin_access_identity,
  :origin_read_timeout)
  SENSITIVE = []
  include Aws::Structure
end