Class: Aws::CloudFront::Types::StreamingDistribution
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::StreamingDistribution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A streaming distribution tells CloudFront where you want RTMP content to be delivered from, and the details about how to track and manage content delivery.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_trusted_signers ⇒ Types::ActiveTrustedSigners
A complex type that lists the Amazon Web Services accounts, if any, that you included in the
TrustedSignerscomplex type for this distribution. -
#arn ⇒ String
The ARN (Amazon Resource Name) for the distribution.
-
#domain_name ⇒ String
The domain name that corresponds to the streaming distribution, for example,
s5c39gqb8ow64r.cloudfront.net. -
#id ⇒ String
The identifier for the RTMP distribution.
-
#last_modified_time ⇒ Time
The date and time that the distribution was last modified.
-
#status ⇒ String
The current status of the RTMP distribution.
-
#streaming_distribution_config ⇒ Types::StreamingDistributionConfig
The current configuration information for the RTMP distribution.
Instance Attribute Details
#active_trusted_signers ⇒ Types::ActiveTrustedSigners
A complex type that lists the Amazon Web Services accounts, if any, that you included in the TrustedSigners complex type for this distribution. These are the accounts that you want to allow to create signed URLs for private content.
The Signer complex type lists the Amazon Web Services account number of the trusted signer or self if the signer is the Amazon Web Services account that created the distribution. The Signer element also includes the IDs of any active CloudFront key pairs that are associated with the trusted signer’s Amazon Web Services account. If no KeyPairId element appears for a Signer, that signer can’t create signed URLs.
For more information, see [Serving Private Content through CloudFront] in the *Amazon CloudFront Developer Guide*.
[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN (Amazon Resource Name) for the distribution. For example: arn:aws:cloudfront::123456789012:distribution/EDFDVBD632BHDS5, where 123456789012 is your Amazon Web Services account ID.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name that corresponds to the streaming distribution, for example, s5c39gqb8ow64r.cloudfront.net.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier for the RTMP distribution. For example: EGTXBD79EXAMPLE.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the distribution was last modified.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the RTMP distribution. When the status is Deployed, the distribution’s information is propagated to all CloudFront edge locations.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |
#streaming_distribution_config ⇒ Types::StreamingDistributionConfig
The current configuration information for the RTMP distribution.
14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14174 class StreamingDistribution < Struct.new( :id, :arn, :status, :last_modified_time, :domain_name, :active_trusted_signers, :streaming_distribution_config) SENSITIVE = [] include Aws::Structure end |