Class: Aws::CloudFront::Types::StreamingDistributionConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The RTMP distribution’s configuration information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasesTypes::Aliases

A complex type that contains information about CNAMEs (alternate domain names), if any, for this streaming distribution.

Returns:



14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#caller_referenceString

A unique value (for example, a date-time stamp) that ensures that the request can’t be replayed.

If the value of ‘CallerReference` is new (regardless of the content of the `StreamingDistributionConfig` object), CloudFront creates a new distribution.

If ‘CallerReference` is a value that you already sent in a previous request to create a distribution, CloudFront returns a `DistributionAlreadyExists` error.

Returns:

  • (String)


14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#commentString

Any comments you want to include about the streaming distribution.

Returns:

  • (String)


14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Whether the streaming distribution is enabled to accept user requests for content.

Returns:

  • (Boolean)


14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#loggingTypes::StreamingLoggingConfig

A complex type that controls whether access logs are written for the streaming distribution.



14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#price_classString

A complex type that contains information about price class for this streaming distribution.

Returns:

  • (String)


14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#s3_originTypes::S3Origin

A complex type that contains information about the Amazon S3 bucket from which you want CloudFront to get your media files for distribution.

Returns:



14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_signersTypes::TrustedSigners

A complex type that specifies any Amazon Web Services accounts that you want to permit to create signed URLs for private content. If you want the distribution to use signed URLs, include this element; if you want the distribution to use public URLs, remove this element. For more information, see [Serving Private Content through CloudFront] in the *Amazon CloudFront Developer Guide*.

[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html



14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
# File 'lib/aws-sdk-cloudfront/types.rb', line 14304

class StreamingDistributionConfig < Struct.new(
  :caller_reference,
  :s3_origin,
  :aliases,
  :comment,
  :logging,
  :trusted_signers,
  :price_class,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end