Class: Aws::CloudFront::Types::StreamingDistributionConfigWithTags
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::StreamingDistributionConfigWithTags
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A streaming distribution Configuration and a list of tags to be associated with the streaming distribution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#streaming_distribution_config ⇒ Types::StreamingDistributionConfig
A streaming distribution Configuration.
-
#tags ⇒ Types::Tags
A complex type that contains zero or more
Tagelements.
Instance Attribute Details
#streaming_distribution_config ⇒ Types::StreamingDistributionConfig
A streaming distribution Configuration.
14263 14264 14265 14266 14267 14268 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14263 class StreamingDistributionConfigWithTags < Struct.new( :streaming_distribution_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::Tags
A complex type that contains zero or more Tag elements.
14263 14264 14265 14266 14267 14268 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14263 class StreamingDistributionConfigWithTags < Struct.new( :streaming_distribution_config, :tags) SENSITIVE = [] include Aws::Structure end |