Class: Aws::CloudFront::Types::TrustStore
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::TrustStore
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A trust store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The trust store’s Amazon Resource Name (ARN).
-
#id ⇒ String
The trust store’s ID.
-
#last_modified_time ⇒ Time
The trust store’s last modified time.
-
#name ⇒ String
The trust store’s name.
-
#number_of_ca_certificates ⇒ Integer
The trust store’s number of CA certificates.
-
#reason ⇒ String
The trust store’s reason.
-
#status ⇒ String
The trust store’s status.
-
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether the trust store uses the CA certificate’s OCSP endpoint to check certificate revocation status.
Instance Attribute Details
#arn ⇒ String
The trust store’s Amazon Resource Name (ARN).
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The trust store’s ID.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The trust store’s last modified time.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The trust store’s name.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#number_of_ca_certificates ⇒ Integer
The trust store’s number of CA certificates.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The trust store’s reason.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The trust store’s status.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether the trust store uses the CA certificate’s OCSP endpoint to check certificate revocation status.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15740 class TrustStore < Struct.new( :id, :arn, :name, :status, :number_of_ca_certificates, :last_modified_time, :reason, :use_client_certificate_ocsp_endpoint) SENSITIVE = [] include Aws::Structure end |