Class: Aws::CloudFront::Types::TrustStoreConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::TrustStoreConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A trust store configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advertise_trust_store_ca_names ⇒ Boolean
The configuration to use to advertise trust store CA names.
-
#ignore_certificate_expiry ⇒ Boolean
The configuration to use to ignore certificate expiration.
-
#trust_store_id ⇒ String
The trust store ID.
Instance Attribute Details
#advertise_trust_store_ca_names ⇒ Boolean
The configuration to use to advertise trust store CA names.
15703 15704 15705 15706 15707 15708 15709 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15703 class TrustStoreConfig < Struct.new( :trust_store_id, :advertise_trust_store_ca_names, :ignore_certificate_expiry) SENSITIVE = [] include Aws::Structure end |
#ignore_certificate_expiry ⇒ Boolean
The configuration to use to ignore certificate expiration.
15703 15704 15705 15706 15707 15708 15709 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15703 class TrustStoreConfig < Struct.new( :trust_store_id, :advertise_trust_store_ca_names, :ignore_certificate_expiry) SENSITIVE = [] include Aws::Structure end |
#trust_store_id ⇒ String
The trust store ID.
15703 15704 15705 15706 15707 15708 15709 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 15703 class TrustStoreConfig < Struct.new( :trust_store_id, :advertise_trust_store_ca_names, :ignore_certificate_expiry) SENSITIVE = [] include Aws::Structure end |