Class: Aws::CloudFront::Types::TrustedKeyGroups

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of key groups whose public keys CloudFront can use to verify the signatures of signed URLs and signed cookies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

This field is true if any of the key groups in the list have public keys that CloudFront can use to verify the signatures of signed URLs and signed cookies. If not, this field is false.

Returns:

  • (Boolean)


12257
12258
12259
12260
12261
12262
12263
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257

class TrustedKeyGroups < Struct.new(
  :enabled,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<String>

A list of key groups identifiers.

Returns:

  • (Array<String>)


12257
12258
12259
12260
12261
12262
12263
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257

class TrustedKeyGroups < Struct.new(
  :enabled,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of key groups in the list.

Returns:

  • (Integer)


12257
12258
12259
12260
12261
12262
12263
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257

class TrustedKeyGroups < Struct.new(
  :enabled,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end