Class: Aws::CloudFront::Types::UpdateCachePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::UpdateCachePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_policy_config ⇒ Types::CachePolicyConfig
A cache policy configuration.
-
#id ⇒ String
The unique identifier for the cache policy that you are updating.
-
#if_match ⇒ String
The version of the cache policy that you are updating.
Instance Attribute Details
#cache_policy_config ⇒ Types::CachePolicyConfig
A cache policy configuration.
12355 12356 12357 12358 12359 12360 12361 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12355 class UpdateCachePolicyRequest < Struct.new( :cache_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the cache policy that you are updating. The identifier is returned in a cache behavior’s CachePolicyId field in the response to GetDistributionConfig.
12355 12356 12357 12358 12359 12360 12361 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12355 class UpdateCachePolicyRequest < Struct.new( :cache_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The version of the cache policy that you are updating. The version is returned in the cache policy’s ETag field in the response to GetCachePolicyConfig.
12355 12356 12357 12358 12359 12360 12361 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12355 class UpdateCachePolicyRequest < Struct.new( :cache_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |