Class: Aws::CloudFront::Types::UpdateDomainAssociationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::UpdateDomainAssociationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain that you’re moving.
-
#etag ⇒ String
The current version of the target standard distribution or distribution tenant that was associated with the domain.
-
#resource_id ⇒ String
The intended destination for the domain.
Instance Attribute Details
#domain ⇒ String
The domain that you’re moving.
16433 16434 16435 16436 16437 16438 16439 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16433 class UpdateDomainAssociationResult < Struct.new( :domain, :resource_id, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current version of the target standard distribution or distribution tenant that was associated with the domain.
16433 16434 16435 16436 16437 16438 16439 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16433 class UpdateDomainAssociationResult < Struct.new( :domain, :resource_id, :etag) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The intended destination for the domain.
16433 16434 16435 16436 16437 16438 16439 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16433 class UpdateDomainAssociationResult < Struct.new( :domain, :resource_id, :etag) SENSITIVE = [] include Aws::Structure end |