Class: Aws::CloudFront::Types::UpdateOriginRequestPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::UpdateOriginRequestPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the origin request policy that you are updating.
-
#if_match ⇒ String
The version of the origin request policy that you are updating.
-
#origin_request_policy_config ⇒ Types::OriginRequestPolicyConfig
An origin request policy configuration.
Instance Attribute Details
#id ⇒ String
The unique identifier for the origin request policy that you are updating. The identifier is returned in a cache behavior’s OriginRequestPolicyId field in the response to GetDistributionConfig.
12833 12834 12835 12836 12837 12838 12839 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12833 class UpdateOriginRequestPolicyRequest < Struct.new( :origin_request_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The version of the origin request policy that you are updating. The version is returned in the origin request policy’s ETag field in the response to GetOriginRequestPolicyConfig.
12833 12834 12835 12836 12837 12838 12839 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12833 class UpdateOriginRequestPolicyRequest < Struct.new( :origin_request_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#origin_request_policy_config ⇒ Types::OriginRequestPolicyConfig
An origin request policy configuration.
12833 12834 12835 12836 12837 12838 12839 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12833 class UpdateOriginRequestPolicyRequest < Struct.new( :origin_request_policy_config, :id, :if_match) SENSITIVE = [] include Aws::Structure end |