Class: Aws::CloudFront::Types::UpdateResponseHeadersPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier for the response headers policy that you are updating.



16865
16866
16867
16868
16869
16870
16871
# File 'lib/aws-sdk-cloudfront/types.rb', line 16865

class UpdateResponseHeadersPolicyRequest < Struct.new(
  :response_headers_policy_config,
  :id,
  :if_match)
  SENSITIVE = []
  include Aws::Structure
end

#if_matchString

The version of the response headers policy that you are updating.

The version is returned in the cache policy's ETag field in the response to GetResponseHeadersPolicyConfig.



16865
16866
16867
16868
16869
16870
16871
# File 'lib/aws-sdk-cloudfront/types.rb', line 16865

class UpdateResponseHeadersPolicyRequest < Struct.new(
  :response_headers_policy_config,
  :id,
  :if_match)
  SENSITIVE = []
  include Aws::Structure
end

#response_headers_policy_configTypes::ResponseHeadersPolicyConfig

A response headers policy configuration.



16865
16866
16867
16868
16869
16870
16871
# File 'lib/aws-sdk-cloudfront/types.rb', line 16865

class UpdateResponseHeadersPolicyRequest < Struct.new(
  :response_headers_policy_config,
  :id,
  :if_match)
  SENSITIVE = []
  include Aws::Structure
end