Class: Aws::CloudFront::Types::UpdateTrustStoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::UpdateTrustStoreRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source.
-
#id ⇒ String
The trust store ID.
-
#if_match ⇒ String
The current version (‘ETag` value) of the trust store you are updating.
-
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether to use the CA certificate’s OCSP endpoint to check certificate revocation status.
Instance Attribute Details
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source.
16956 16957 16958 16959 16960 16961 16962 16963 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16956 class UpdateTrustStoreRequest < Struct.new( :id, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :if_match) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The trust store ID.
16956 16957 16958 16959 16960 16961 16962 16963 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16956 class UpdateTrustStoreRequest < Struct.new( :id, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The current version (‘ETag` value) of the trust store you are updating.
16956 16957 16958 16959 16960 16961 16962 16963 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16956 class UpdateTrustStoreRequest < Struct.new( :id, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :if_match) SENSITIVE = [] include Aws::Structure end |
#use_client_certificate_ocsp_endpoint ⇒ Boolean
A Boolean that determines whether to use the CA certificate’s OCSP endpoint to check certificate revocation status.
16956 16957 16958 16959 16960 16961 16962 16963 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 16956 class UpdateTrustStoreRequest < Struct.new( :id, :ca_certificates_bundle_source, :use_client_certificate_ocsp_endpoint, :if_match) SENSITIVE = [] include Aws::Structure end |