Class: Aws::CloudFront::Types::VpcOrigin
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::VpcOrigin
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
An Amazon CloudFront VPC origin.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID of the Amazon Web Services account that owns the VPC origin.
-
#arn ⇒ String
The VPC origin ARN.
-
#created_time ⇒ Time
The VPC origin created time.
-
#id ⇒ String
The VPC origin ID.
-
#last_modified_time ⇒ Time
The VPC origin last modified time.
-
#status ⇒ String
The VPC origin status.
-
#vpc_origin_endpoint_config ⇒ Types::VpcOriginEndpointConfig
The VPC origin endpoint configuration.
Instance Attribute Details
#account_id ⇒ String
The account ID of the Amazon Web Services account that owns the VPC origin.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The VPC origin ARN.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The VPC origin created time.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The VPC origin ID.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The VPC origin last modified time.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The VPC origin status.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |
#vpc_origin_endpoint_config ⇒ Types::VpcOriginEndpointConfig
The VPC origin endpoint configuration.
17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17260 class VpcOrigin < Struct.new( :id, :arn, :account_id, :status, :created_time, :last_modified_time, :vpc_origin_endpoint_config) SENSITIVE = [] include Aws::Structure end |