Class: Aws::CloudFront::Types::VpcOriginConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

An Amazon CloudFront VPC origin configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#origin_keepalive_timeoutInteger

Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don't specify otherwise) is 5 seconds.

For more information, see Keep-alive timeout (custom origins only) in the Amazon CloudFront Developer Guide.

Returns:

  • (Integer)


17392
17393
17394
17395
17396
17397
17398
17399
# File 'lib/aws-sdk-cloudfront/types.rb', line 17392

class VpcOriginConfig < Struct.new(
  :vpc_origin_id,
  :owner_account_id,
  :origin_read_timeout,
  :origin_keepalive_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#origin_read_timeoutInteger

Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the origin response timeout. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don't specify otherwise) is 30 seconds.

For more information, see Response timeout in the Amazon CloudFront Developer Guide.

Returns:

  • (Integer)


17392
17393
17394
17395
17396
17397
17398
17399
# File 'lib/aws-sdk-cloudfront/types.rb', line 17392

class VpcOriginConfig < Struct.new(
  :vpc_origin_id,
  :owner_account_id,
  :origin_read_timeout,
  :origin_keepalive_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#owner_account_idString

The account ID of the Amazon Web Services account that owns the VPC origin.

Returns:

  • (String)


17392
17393
17394
17395
17396
17397
17398
17399
# File 'lib/aws-sdk-cloudfront/types.rb', line 17392

class VpcOriginConfig < Struct.new(
  :vpc_origin_id,
  :owner_account_id,
  :origin_read_timeout,
  :origin_keepalive_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_origin_idString

The VPC origin ID.

Returns:

  • (String)


17392
17393
17394
17395
17396
17397
17398
17399
# File 'lib/aws-sdk-cloudfront/types.rb', line 17392

class VpcOriginConfig < Struct.new(
  :vpc_origin_id,
  :owner_account_id,
  :origin_read_timeout,
  :origin_keepalive_timeout)
  SENSITIVE = []
  include Aws::Structure
end