Class: Aws::CloudFront::Types::VpcOriginList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of CloudFront VPC origins.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether more VPC origins remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more VPC origins in the list.

Returns:

  • (Boolean)


17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::VpcOriginSummary>

The items of the VPC origins list.

Returns:



17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The marker associated with the VPC origins list.

Returns:

  • (String)


17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of items included in the list.

Returns:

  • (Integer)


17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

The next marker associated with the VPC origins list.

Returns:

  • (String)


17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of VPC origins in the list.

Returns:

  • (Integer)


17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397

class VpcOriginList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end