Class: Aws::CloudFront::Types::ContentTypeProfileConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ContentTypeProfileConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The configuration for a field-level encryption content type-profile mapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type_profiles ⇒ Types::ContentTypeProfiles
The configuration for a field-level encryption content type-profile.
-
#forward_when_content_type_is_unknown ⇒ Boolean
The setting in a field-level encryption content type-profile mapping that specifies what to do when an unknown content type is provided for the profile.
Instance Attribute Details
#content_type_profiles ⇒ Types::ContentTypeProfiles
The configuration for a field-level encryption content type-profile.
2017 2018 2019 2020 2021 2022 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2017 class ContentTypeProfileConfig < Struct.new( :forward_when_content_type_is_unknown, :content_type_profiles) SENSITIVE = [] include Aws::Structure end |
#forward_when_content_type_is_unknown ⇒ Boolean
The setting in a field-level encryption content type-profile mapping that specifies what to do when an unknown content type is provided for the profile. If true, content is forwarded without being encrypted when the content type is unknown. If false (the default), an error is returned when the content type is unknown.
2017 2018 2019 2020 2021 2022 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 2017 class ContentTypeProfileConfig < Struct.new( :forward_when_content_type_is_unknown, :content_type_profiles) SENSITIVE = [] include Aws::Structure end |