Class: Aws::CloudFront::Types::ContinuousDeploymentPolicyList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Contains a list of continuous deployment policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::ContinuousDeploymentPolicySummary>

A list of continuous deployment policy items.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-cloudfront/types.rb', line 2126

class ContinuousDeploymentPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of continuous deployment policies that were specified in your request.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-cloudfront/types.rb', line 2126

class ContinuousDeploymentPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

Indicates the next page of continuous deployment policies. To get the next page of the list, use this value in the Marker field of your request.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-cloudfront/types.rb', line 2126

class ContinuousDeploymentPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The total number of continuous deployment policies in your Amazon Web Services account, regardless of the MaxItems value.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-cloudfront/types.rb', line 2126

class ContinuousDeploymentPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end