Class: Aws::CloudFront::Types::CreateTrustStoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::CreateTrustStoreRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source for the trust store.
-
#name ⇒ String
A name for the trust store.
-
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
Instance Attribute Details
#ca_certificates_bundle_source ⇒ Types::CaCertificatesBundleSource
The CA certificates bundle source for the trust store.
3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3452 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the trust store.
3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3452 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::Tags
A complex type that contains zero or more ‘Tag` elements.
3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3452 class CreateTrustStoreRequest < Struct.new( :name, :ca_certificates_bundle_source, :tags) SENSITIVE = [] include Aws::Structure end |