Class: Aws::CloudFront::Types::Customizations
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::Customizations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Customizations for the distribution tenant. For each distribution tenant, you can specify the geographic restrictions, and the Amazon Resource Names (ARNs) for the ACM certificate and WAF web ACL. These are specific values that you can override or disable from the multi-tenant distribution that was used to create the distribution tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate ⇒ Types::Certificate
The Certificate Manager (ACM) certificate.
-
#geo_restrictions ⇒ Types::GeoRestrictionCustomization
The geographic restrictions.
-
#web_acl ⇒ Types::WebAclCustomization
The WAF web ACL.
Instance Attribute Details
#certificate ⇒ Types::Certificate
The Certificate Manager (ACM) certificate.
3783 3784 3785 3786 3787 3788 3789 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3783 class Customizations < Struct.new( :web_acl, :certificate, :geo_restrictions) SENSITIVE = [] include Aws::Structure end |
#geo_restrictions ⇒ Types::GeoRestrictionCustomization
The geographic restrictions.
3783 3784 3785 3786 3787 3788 3789 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3783 class Customizations < Struct.new( :web_acl, :certificate, :geo_restrictions) SENSITIVE = [] include Aws::Structure end |
#web_acl ⇒ Types::WebAclCustomization
The WAF web ACL.
3783 3784 3785 3786 3787 3788 3789 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3783 class Customizations < Struct.new( :web_acl, :certificate, :geo_restrictions) SENSITIVE = [] include Aws::Structure end |