Class: Aws::CloudFront::Types::DeleteKeyGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DeleteKeyGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the key group that you are deleting.
-
#if_match ⇒ String
The version of the key group that you are deleting.
Instance Attribute Details
#id ⇒ String
The identifier of the key group that you are deleting. To get the identifier, use ListKeyGroups.
3189 3190 3191 3192 3193 3194 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3189 class DeleteKeyGroupRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The version of the key group that you are deleting. The version is the key group’s ETag value. To get the ETag, use GetKeyGroup or GetKeyGroupConfig.
3189 3190 3191 3192 3193 3194 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3189 class DeleteKeyGroupRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |