Class: Aws::CloudFront::Types::DeleteOriginRequestPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DeleteOriginRequestPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the origin request policy that you are deleting.
-
#if_match ⇒ String
The version of the origin request policy that you are deleting.
Instance Attribute Details
#id ⇒ String
The unique identifier for the origin request policy that you are deleting. To get the identifier, you can use ListOriginRequestPolicies.
3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3263 class DeleteOriginRequestPolicyRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The version of the origin request policy that you are deleting. The version is the origin request policy’s ETag value, which you can get using ListOriginRequestPolicies, GetOriginRequestPolicy, or GetOriginRequestPolicyConfig.
3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 3263 class DeleteOriginRequestPolicyRequest < Struct.new( :id, :if_match) SENSITIVE = [] include Aws::Structure end |