Class: Aws::CloudFront::Types::DistributionIdOwnerList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DistributionIdOwnerList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The list of distribution IDs and the Amazon Web Services accounts that they belong to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more
DistributionIdOwnerobjects remain to be listed. -
#items ⇒ Array<Types::DistributionIdOwner>
The number of
DistributionIdOwnerobjects. -
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of
DistributionIdOwnerobjects. -
#max_items ⇒ Integer
The maximum number of
DistributionIdOwnerobjects to return. -
#next_marker ⇒ String
A token used for pagination of results returned in the response.
-
#quantity ⇒ Integer
Specifies the actual number of
DistributionIdOwnerobjects included in the list for the current page.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more DistributionIdOwner objects remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more results in the list.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::DistributionIdOwner>
The number of DistributionIdOwner objects.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of DistributionIdOwner objects. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of DistributionIdOwner objects to return.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
Specifies the actual number of DistributionIdOwner objects included in the list for the current page.
5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5397 class DistributionIdOwnerList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |