Class: Aws::CloudFront::Types::DistributionList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::DistributionList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A distribution list.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more distributions remain to be listed.
-
#items ⇒ Array<Types::DistributionSummary>
A complex type that contains one
DistributionSummaryelement for each distribution that was created by the current Amazon Web Services account. -
#marker ⇒ String
The value you provided for the
Markerrequest parameter. -
#max_items ⇒ Integer
The value you provided for the
MaxItemsrequest parameter. -
#next_marker ⇒ String
If
IsTruncatedistrue, this element is present and contains the value you can use for theMarkerrequest parameter to continue listing your distributions where they left off. -
#quantity ⇒ Integer
The number of distributions that were created by the current Amazon Web Services account.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more distributions remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more distributions in the list.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::DistributionSummary>
A complex type that contains one DistributionSummary element for each distribution that was created by the current Amazon Web Services account.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The value you provided for the Marker request parameter.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The value you provided for the MaxItems request parameter.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your distributions where they left off.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of distributions that were created by the current Amazon Web Services account.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 5444 class DistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |