Class: Aws::CloudFront::Types::FieldLevelEncryptionList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::FieldLevelEncryptionList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
List of field-level encryption configurations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::FieldLevelEncryptionSummary>
An array of field-level encryption items.
-
#max_items ⇒ Integer
The maximum number of elements you want in the response body.
-
#next_marker ⇒ String
If there are more elements to be listed, this element is present and contains the value that you can use for the
Markerrequest parameter to continue listing your configurations where you left off. -
#quantity ⇒ Integer
The number of field-level encryption items.
Instance Attribute Details
#items ⇒ Array<Types::FieldLevelEncryptionSummary>
An array of field-level encryption items.
6263 6264 6265 6266 6267 6268 6269 6270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263 class FieldLevelEncryptionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of elements you want in the response body.
6263 6264 6265 6266 6267 6268 6269 6270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263 class FieldLevelEncryptionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more elements to be listed, this element is present and
contains the value that you can use for the Marker request
parameter to continue listing your configurations where you left
off.
6263 6264 6265 6266 6267 6268 6269 6270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263 class FieldLevelEncryptionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of field-level encryption items.
6263 6264 6265 6266 6267 6268 6269 6270 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6263 class FieldLevelEncryptionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |