Class: Aws::CloudFront::Types::FieldLevelEncryptionProfileSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The field-level encryption profile summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commentString

An optional comment for the field-level encryption profile summary. The comment cannot be longer than 128 characters.

Returns:

  • (String)


6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/aws-sdk-cloudfront/types.rb', line 6414

class FieldLevelEncryptionProfileSummary < Struct.new(
  :id,
  :last_modified_time,
  :name,
  :encryption_entities,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_entitiesTypes::EncryptionEntities

A complex data type of encryption entities for the field-level encryption profile that include the public key ID, provider, and field patterns for specifying which fields to encrypt with this key.



6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/aws-sdk-cloudfront/types.rb', line 6414

class FieldLevelEncryptionProfileSummary < Struct.new(
  :id,
  :last_modified_time,
  :name,
  :encryption_entities,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#idString

ID for the field-level encryption profile summary.

Returns:

  • (String)


6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/aws-sdk-cloudfront/types.rb', line 6414

class FieldLevelEncryptionProfileSummary < Struct.new(
  :id,
  :last_modified_time,
  :name,
  :encryption_entities,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time when the field-level encryption profile summary was last updated.

Returns:

  • (Time)


6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/aws-sdk-cloudfront/types.rb', line 6414

class FieldLevelEncryptionProfileSummary < Struct.new(
  :id,
  :last_modified_time,
  :name,
  :encryption_entities,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name for the field-level encryption profile summary.

Returns:

  • (String)


6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/aws-sdk-cloudfront/types.rb', line 6414

class FieldLevelEncryptionProfileSummary < Struct.new(
  :id,
  :last_modified_time,
  :name,
  :encryption_entities,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end