Class: Aws::CloudFront::Types::FunctionList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::FunctionList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of CloudFront functions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::FunctionSummary>
Contains the functions in the list.
-
#max_items ⇒ Integer
The maximum number of functions requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The number of functions returned in the response.
Instance Attribute Details
#items ⇒ Array<Types::FunctionSummary>
Contains the functions in the list.
6781 6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781 class FunctionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of functions requested.
6781 6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781 class FunctionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this
element is present. It contains the value that you should use in the
Marker field of a subsequent request to continue listing functions
where you left off.
6781 6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781 class FunctionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of functions returned in the response.
6781 6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 6781 class FunctionList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |