Class: Aws::CloudFront::Types::InvalidForwardCookies
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::InvalidForwardCookies
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Your request contains forward cookies option which doesn’t match with the expectation for the whitelisted list of cookie names. Either list of cookie names has been specified when not allowed or list of cookie names is missing when expected.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
8359 8360 8361 8362 8363 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8359 class InvalidForwardCookies < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |