Class: Aws::CloudFront::Types::KeyGroupList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of key groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::KeyGroupSummary>

A list of key groups.



8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of key groups requested.



8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing key groups.



8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of key groups returned in the response.



8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975

class KeyGroupList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end