Class: Aws::CloudFront::Types::KeyGroupList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::KeyGroupList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of key groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::KeyGroupSummary>
A list of key groups.
-
#max_items ⇒ Integer
The maximum number of key groups requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The number of key groups returned in the response.
Instance Attribute Details
#items ⇒ Array<Types::KeyGroupSummary>
A list of key groups.
8975 8976 8977 8978 8979 8980 8981 8982 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975 class KeyGroupList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of key groups requested.
8975 8976 8977 8978 8979 8980 8981 8982 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975 class KeyGroupList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing key groups.
8975 8976 8977 8978 8979 8980 8981 8982 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975 class KeyGroupList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of key groups returned in the response.
8975 8976 8977 8978 8979 8980 8981 8982 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8975 class KeyGroupList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |