Class: Aws::CloudFront::Types::ListCachePoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListCachePoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of cache policies.
-
#max_items ⇒ Integer
The maximum number of cache policies that you want in the response.
-
#type ⇒ String
A filter to return only the specified kinds of cache policies.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of cache policies. The response includes cache policies in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9297 class ListCachePoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of cache policies that you want in the response.
9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9297 class ListCachePoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
A filter to return only the specified kinds of cache policies. Valid values are:
-
managed– Returns only the managed policies created by Amazon Web Services. -
custom– Returns only the custom policies created in your Amazon Web Services account.
9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9297 class ListCachePoliciesRequest < Struct.new( :type, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |