Class: Aws::CloudFront::Types::ListCloudFrontOriginAccessIdentitiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListCloudFrontOriginAccessIdentitiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The request to list origin access identities.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of origin access identities.
-
#max_items ⇒ Integer
The maximum number of origin access identities you want in the response body.
Instance Attribute Details
#marker ⇒ String
Use this when paginating results to indicate where to begin in your
list of origin access identities. The results include identities in
the list that occur after the marker. To get the next page of
results, set the Marker to the value of the NextMarker from the
current page's response (which is also the ID of the last identity
on that page).
9395 9396 9397 9398 9399 9400 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9395 class ListCloudFrontOriginAccessIdentitiesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin access identities you want in the response body.
9395 9396 9397 9398 9399 9400 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9395 class ListCloudFrontOriginAccessIdentitiesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |