Class: Aws::CloudFront::Types::ListConflictingAliasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListConflictingAliasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias (also called a CNAME) to search for conflicting aliases.
-
#distribution_id ⇒ String
The ID of a standard distribution in your account that has an attached TLS certificate that includes the provided alias.
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in the list of conflicting aliases.
-
#max_items ⇒ Integer
The maximum number of conflicting aliases that you want in the response.
Instance Attribute Details
#alias ⇒ String
The alias (also called a CNAME) to search for conflicting aliases.
9440 9441 9442 9443 9444 9445 9446 9447 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440 class ListConflictingAliasesRequest < Struct.new( :distribution_id, :alias, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#distribution_id ⇒ String
The ID of a standard distribution in your account that has an attached TLS certificate that includes the provided alias.
9440 9441 9442 9443 9444 9445 9446 9447 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440 class ListConflictingAliasesRequest < Struct.new( :distribution_id, :alias, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
the list of conflicting aliases. The response includes conflicting
aliases in the list that occur after the marker. To get the next
page of the list, set this field's value to the value of
NextMarker from the current page's response.
9440 9441 9442 9443 9444 9445 9446 9447 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440 class ListConflictingAliasesRequest < Struct.new( :distribution_id, :alias, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of conflicting aliases that you want in the response.
9440 9441 9442 9443 9444 9445 9446 9447 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440 class ListConflictingAliasesRequest < Struct.new( :distribution_id, :alias, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |