Class: Aws::CloudFront::Types::ListConnectionFunctionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


9420
9421
9422
9423
9424
9425
9426
# File 'lib/aws-sdk-cloudfront/types.rb', line 9420

class ListConnectionFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of connection functions that you want returned in the response.

Returns:

  • (Integer)


9420
9421
9422
9423
9424
9425
9426
# File 'lib/aws-sdk-cloudfront/types.rb', line 9420

class ListConnectionFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#stageString

The connection function’s stage.

Returns:

  • (String)


9420
9421
9422
9423
9424
9425
9426
# File 'lib/aws-sdk-cloudfront/types.rb', line 9420

class ListConnectionFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end