Class: Aws::CloudFront::Types::ListConnectionFunctionsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_functionsArray<Types::ConnectionFunctionSummary>

A list of connection functions.



9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConnectionFunctionsResult < Struct.new(
  :next_marker,
  :connection_functions)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

Indicates the next page of connection functions. To get the next page of the list, use this value in the Marker field of your request.

Returns:

  • (String)


9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-cloudfront/types.rb', line 9440

class ListConnectionFunctionsResult < Struct.new(
  :next_marker,
  :connection_functions)
  SENSITIVE = []
  include Aws::Structure
end