Class: Aws::CloudFront::Types::ListConnectionGroupsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListConnectionGroupsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_groups ⇒ Array<Types::ConnectionGroupSummary>
The list of connection groups that you retrieved.
-
#next_marker ⇒ String
A token used for pagination of results returned in the response.
Instance Attribute Details
#connection_groups ⇒ Array<Types::ConnectionGroupSummary>
The list of connection groups that you retrieved.
9481 9482 9483 9484 9485 9486 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9481 class ListConnectionGroupsResult < Struct.new( :next_marker, :connection_groups) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.
9481 9482 9483 9484 9485 9486 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9481 class ListConnectionGroupsResult < Struct.new( :next_marker, :connection_groups) SENSITIVE = [] include Aws::Structure end |