Class: Aws::CloudFront::Types::ListContinuousDeploymentPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListContinuousDeploymentPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of continuous deployment policies.
-
#max_items ⇒ Integer
The maximum number of continuous deployment policies that you want returned in the response.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of continuous deployment policies. The response includes
policies in the list that occur after the marker. To get the next
page of the list, set this field's value to the value of
NextMarker from the current page's response.
9563 9564 9565 9566 9567 9568 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9563 class ListContinuousDeploymentPoliciesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of continuous deployment policies that you want returned in the response.
9563 9564 9565 9566 9567 9568 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9563 class ListContinuousDeploymentPoliciesRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |