Class: Aws::CloudFront::Types::ListDistributionTenantsByCustomizationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionTenantsByCustomizationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution_tenant_list ⇒ Array<Types::DistributionTenantSummary>
A list of distribution tenants with the specified customization.
-
#next_marker ⇒ String
A token used for pagination of results returned in the response.
Instance Attribute Details
#distribution_tenant_list ⇒ Array<Types::DistributionTenantSummary>
A list of distribution tenants with the specified customization.
9562 9563 9564 9565 9566 9567 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9562 class ListDistributionTenantsByCustomizationResult < Struct.new( :next_marker, :distribution_tenant_list) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.
9562 9563 9564 9565 9566 9567 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9562 class ListDistributionTenantsByCustomizationResult < Struct.new( :next_marker, :distribution_tenant_list) SENSITIVE = [] include Aws::Structure end |