Class: Aws::CloudFront::Types::ListDistributionsByAnycastIpListIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByAnycastIpListIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list.
-
#max_items ⇒ Integer
The maximum number of distributions that you want returned in the response.
Instance Attribute Details
#anycast_ip_list_id ⇒ String
The ID of the Anycast static IP list.
9629 9630 9631 9632 9633 9634 9635 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629 class ListDistributionsByAnycastIpListIdRequest < Struct.new( :marker, :max_items, :anycast_ip_list_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9629 9630 9631 9632 9633 9634 9635 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629 class ListDistributionsByAnycastIpListIdRequest < Struct.new( :marker, :max_items, :anycast_ip_list_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distributions that you want returned in the response.
9629 9630 9631 9632 9633 9634 9635 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9629 class ListDistributionsByAnycastIpListIdRequest < Struct.new( :marker, :max_items, :anycast_ip_list_id) SENSITIVE = [] include Aws::Structure end |