Class: Aws::CloudFront::Types::ListDistributionsByCachePolicyIdRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_policy_idString

The ID of the cache policy whose associated distribution IDs you want to list.

Returns:

  • (String)


9669
9670
9671
9672
9673
9674
9675
# File 'lib/aws-sdk-cloudfront/types.rb', line 9669

class ListDistributionsByCachePolicyIdRequest < Struct.new(
  :marker,
  :max_items,
  :cache_policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in your list of distribution IDs. The response includes distribution IDs in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


9669
9670
9671
9672
9673
9674
9675
# File 'lib/aws-sdk-cloudfront/types.rb', line 9669

class ListDistributionsByCachePolicyIdRequest < Struct.new(
  :marker,
  :max_items,
  :cache_policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distribution IDs that you want in the response.

Returns:

  • (Integer)


9669
9670
9671
9672
9673
9674
9675
# File 'lib/aws-sdk-cloudfront/types.rb', line 9669

class ListDistributionsByCachePolicyIdRequest < Struct.new(
  :marker,
  :max_items,
  :cache_policy_id)
  SENSITIVE = []
  include Aws::Structure
end