Class: Aws::CloudFront::Types::ListDistributionsByConnectionFunctionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_function_identifierString

The distributions by connection function identifier.

Returns:

  • (String)


9708
9709
9710
9711
9712
9713
9714
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708

class ListDistributionsByConnectionFunctionRequest < Struct.new(
  :marker,
  :max_items,
  :connection_function_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


9708
9709
9710
9711
9712
9713
9714
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708

class ListDistributionsByConnectionFunctionRequest < Struct.new(
  :marker,
  :max_items,
  :connection_function_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of distributions that you want returned in the response.

Returns:

  • (Integer)


9708
9709
9710
9711
9712
9713
9714
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708

class ListDistributionsByConnectionFunctionRequest < Struct.new(
  :marker,
  :max_items,
  :connection_function_identifier)
  SENSITIVE = []
  include Aws::Structure
end