Class: Aws::CloudFront::Types::ListDistributionsByConnectionFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByConnectionFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_function_identifier ⇒ String
The distributions by connection function identifier.
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list.
-
#max_items ⇒ Integer
The maximum number of distributions that you want returned in the response.
Instance Attribute Details
#connection_function_identifier ⇒ String
The distributions by connection function identifier.
9708 9709 9710 9711 9712 9713 9714 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708 class ListDistributionsByConnectionFunctionRequest < Struct.new( :marker, :max_items, :connection_function_identifier) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9708 9709 9710 9711 9712 9713 9714 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708 class ListDistributionsByConnectionFunctionRequest < Struct.new( :marker, :max_items, :connection_function_identifier) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distributions that you want returned in the response.
9708 9709 9710 9711 9712 9713 9714 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9708 class ListDistributionsByConnectionFunctionRequest < Struct.new( :marker, :max_items, :connection_function_identifier) SENSITIVE = [] include Aws::Structure end |