Class: Aws::CloudFront::Types::ListDistributionsByKeyGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByKeyGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_group_id ⇒ String
The ID of the key group whose associated distribution IDs you are listing.
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs.
-
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
Instance Attribute Details
#key_group_id ⇒ String
The ID of the key group whose associated distribution IDs you are listing.
9784 9785 9786 9787 9788 9789 9790 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9784 class ListDistributionsByKeyGroupRequest < Struct.new( :marker, :max_items, :key_group_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs. The response includes distribution IDs in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9784 9785 9786 9787 9788 9789 9790 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9784 class ListDistributionsByKeyGroupRequest < Struct.new( :marker, :max_items, :key_group_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
9784 9785 9786 9787 9788 9789 9790 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9784 class ListDistributionsByKeyGroupRequest < Struct.new( :marker, :max_items, :key_group_id) SENSITIVE = [] include Aws::Structure end |