Class: Aws::CloudFront::Types::ListDistributionsByOriginRequestPolicyIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByOriginRequestPolicyIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs.
-
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
-
#origin_request_policy_id ⇒ String
The ID of the origin request policy whose associated distribution IDs you want to list.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs. The response includes distribution IDs in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9824 9825 9826 9827 9828 9829 9830 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9824 class ListDistributionsByOriginRequestPolicyIdRequest < Struct.new( :marker, :max_items, :origin_request_policy_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution IDs that you want in the response.
9824 9825 9826 9827 9828 9829 9830 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9824 class ListDistributionsByOriginRequestPolicyIdRequest < Struct.new( :marker, :max_items, :origin_request_policy_id) SENSITIVE = [] include Aws::Structure end |
#origin_request_policy_id ⇒ String
The ID of the origin request policy whose associated distribution IDs you want to list.
9824 9825 9826 9827 9828 9829 9830 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9824 class ListDistributionsByOriginRequestPolicyIdRequest < Struct.new( :marker, :max_items, :origin_request_policy_id) SENSITIVE = [] include Aws::Structure end |