Class: Aws::CloudFront::Types::ListDistributionsByOwnedResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByOwnedResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distributions.
-
#max_items ⇒ Integer
The maximum number of distributions to return.
-
#resource_arn ⇒ String
The ARN of the CloudFront resource that you’ve shared with other Amazon Web Services accounts.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distributions. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
9863 9864 9865 9866 9867 9868 9869 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9863 class ListDistributionsByOwnedResourceRequest < Struct.new( :resource_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distributions to return.
9863 9864 9865 9866 9867 9868 9869 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9863 class ListDistributionsByOwnedResourceRequest < Struct.new( :resource_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the CloudFront resource that you’ve shared with other Amazon Web Services accounts.
9863 9864 9865 9866 9867 9868 9869 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 9863 class ListDistributionsByOwnedResourceRequest < Struct.new( :resource_arn, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |