Class: Aws::CloudFront::Types::ListDistributionsByResponseHeadersPolicyIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDistributionsByResponseHeadersPolicyIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of distribution IDs.
-
#max_items ⇒ Integer
The maximum number of distribution IDs that you want to get in the response.
-
#response_headers_policy_id ⇒ String
The ID of the response headers policy whose associated distribution IDs you want to list.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in
your list of distribution IDs. The response includes distribution
IDs in the list that occur after the marker. To get the next page of
the list, set this field's value to the value of NextMarker from
the current page's response.
10008 10009 10010 10011 10012 10013 10014 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10008 class ListDistributionsByResponseHeadersPolicyIdRequest < Struct.new( :marker, :max_items, :response_headers_policy_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of distribution IDs that you want to get in the response.
10008 10009 10010 10011 10012 10013 10014 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10008 class ListDistributionsByResponseHeadersPolicyIdRequest < Struct.new( :marker, :max_items, :response_headers_policy_id) SENSITIVE = [] include Aws::Structure end |
#response_headers_policy_id ⇒ String
The ID of the response headers policy whose associated distribution IDs you want to list.
10008 10009 10010 10011 10012 10013 10014 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10008 class ListDistributionsByResponseHeadersPolicyIdRequest < Struct.new( :marker, :max_items, :response_headers_policy_id) SENSITIVE = [] include Aws::Structure end |