Class: Aws::CloudFront::Types::ListDomainConflictsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListDomainConflictsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_conflicts ⇒ Array<Types::DomainConflict>
Contains details about the domain conflicts.
-
#next_marker ⇒ String
A token used for pagination of results returned in the response.
Instance Attribute Details
#domain_conflicts ⇒ Array<Types::DomainConflict>
Contains details about the domain conflicts.
10176 10177 10178 10179 10180 10181 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10176 class ListDomainConflictsResult < Struct.new( :domain_conflicts, :next_marker) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
A token used for pagination of results returned in the response. You can use the token from the previous request to define where the current request should begin.
10176 10177 10178 10179 10180 10181 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10176 class ListDomainConflictsResult < Struct.new( :domain_conflicts, :next_marker) SENSITIVE = [] include Aws::Structure end |