Class: Aws::CloudFront::Types::ListFunctionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of functions. The response includes functions in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of ‘NextMarker` from the current page’s response.

Returns:

  • (String)


9747
9748
9749
9750
9751
9752
9753
# File 'lib/aws-sdk-cloudfront/types.rb', line 9747

class ListFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of functions that you want in the response.

Returns:

  • (Integer)


9747
9748
9749
9750
9751
9752
9753
# File 'lib/aws-sdk-cloudfront/types.rb', line 9747

class ListFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#stageString

An optional filter to return only the functions that are in the specified stage, either ‘DEVELOPMENT` or `LIVE`.

Returns:

  • (String)


9747
9748
9749
9750
9751
9752
9753
# File 'lib/aws-sdk-cloudfront/types.rb', line 9747

class ListFunctionsRequest < Struct.new(
  :marker,
  :max_items,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end