Class: Aws::CloudFront::Types::ListKeyGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListKeyGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of key groups.
-
#max_items ⇒ Integer
The maximum number of key groups that you want in the response.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of key groups. The response includes key groups in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
10402 10403 10404 10405 10406 10407 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10402 class ListKeyGroupsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of key groups that you want in the response.
10402 10403 10404 10405 10406 10407 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10402 class ListKeyGroupsRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |