Class: Aws::CloudFront::Types::ListPublicKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListPublicKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of public keys.
-
#max_items ⇒ Integer
The maximum number of public keys you want in the response body.
Instance Attribute Details
#marker ⇒ String
Use this when paginating results to indicate where to begin in your list of public keys. The results include public keys in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page’s response (which is also the ID of the last public key on that page).
10550 10551 10552 10553 10554 10555 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10550 class ListPublicKeysRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of public keys you want in the response body.
10550 10551 10552 10553 10554 10555 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10550 class ListPublicKeysRequest < Struct.new( :marker, :max_items) SENSITIVE = [] include Aws::Structure end |