Class: Aws::CloudFront::Types::ListRealtimeLogConfigsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this field when paginating results to indicate where to begin in your list of real-time log configurations. The response includes real-time log configurations in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.

Returns:

  • (String)


10585
10586
10587
10588
10589
10590
# File 'lib/aws-sdk-cloudfront/types.rb', line 10585

class ListRealtimeLogConfigsRequest < Struct.new(
  :max_items,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of real-time log configurations that you want in the response.

Returns:

  • (Integer)


10585
10586
10587
10588
10589
10590
# File 'lib/aws-sdk-cloudfront/types.rb', line 10585

class ListRealtimeLogConfigsRequest < Struct.new(
  :max_items,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end