Class: Aws::CloudFront::Types::ListRealtimeLogConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListRealtimeLogConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of real-time log configurations.
-
#max_items ⇒ Integer
The maximum number of real-time log configurations that you want in the response.
Instance Attribute Details
#marker ⇒ String
Use this field when paginating results to indicate where to begin in your list of real-time log configurations. The response includes real-time log configurations in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response.
10585 10586 10587 10588 10589 10590 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10585 class ListRealtimeLogConfigsRequest < Struct.new( :max_items, :marker) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of real-time log configurations that you want in the response.
10585 10586 10587 10588 10589 10590 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10585 class ListRealtimeLogConfigsRequest < Struct.new( :max_items, :marker) SENSITIVE = [] include Aws::Structure end |