Class: Aws::CloudFront::Types::ListTrustStoresResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ListTrustStoresResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
Indicates the next page of trust stores.
-
#trust_store_list ⇒ Array<Types::TrustStoreSummary>
The trust store list.
Instance Attribute Details
#next_marker ⇒ String
Indicates the next page of trust stores. To get the next page of the list, use this value in the Marker field of your request.
10738 10739 10740 10741 10742 10743 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10738 class ListTrustStoresResult < Struct.new( :next_marker, :trust_store_list) SENSITIVE = [] include Aws::Structure end |
#trust_store_list ⇒ Array<Types::TrustStoreSummary>
The trust store list.
10738 10739 10740 10741 10742 10743 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10738 class ListTrustStoresResult < Struct.new( :next_marker, :trust_store_list) SENSITIVE = [] include Aws::Structure end |