Class: Aws::CloudFront::Types::ManagedCertificateDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ManagedCertificateDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Contains details about the CloudFront managed ACM certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN of the CloudFront managed ACM certificate.
-
#certificate_status ⇒ String
The status of the CloudFront managed ACM certificate.
-
#validation_token_details ⇒ Array<Types::ValidationTokenDetail>
Contains details about the validation token of the specified CloudFront managed ACM certificate.
-
#validation_token_host ⇒ String
Contains details about the validation token host of the specified CloudFront managed ACM certificate.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN of the CloudFront managed ACM certificate.
10885 10886 10887 10888 10889 10890 10891 10892 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10885 class ManagedCertificateDetails < Struct.new( :certificate_arn, :certificate_status, :validation_token_host, :validation_token_details) SENSITIVE = [] include Aws::Structure end |
#certificate_status ⇒ String
The status of the CloudFront managed ACM certificate.
<note markdown=“1”> Your distribution tenant will be updated with the latest certificate status. When calling the [UpdateDistributionTenant] operation, use the latest value for the ‘ETag`.
</note>
[1]: docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistributionTenant.html
10885 10886 10887 10888 10889 10890 10891 10892 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10885 class ManagedCertificateDetails < Struct.new( :certificate_arn, :certificate_status, :validation_token_host, :validation_token_details) SENSITIVE = [] include Aws::Structure end |
#validation_token_details ⇒ Array<Types::ValidationTokenDetail>
Contains details about the validation token of the specified CloudFront managed ACM certificate.
10885 10886 10887 10888 10889 10890 10891 10892 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10885 class ManagedCertificateDetails < Struct.new( :certificate_arn, :certificate_status, :validation_token_host, :validation_token_details) SENSITIVE = [] include Aws::Structure end |
#validation_token_host ⇒ String
Contains details about the validation token host of the specified CloudFront managed ACM certificate.
-
For ‘cloudfront`, CloudFront will automatically serve the validation token. Choose this mode if you can point the domain’s DNS to CloudFront immediately.
-
For ‘self-hosted`, you serve the validation token from your existing infrastructure. Choose this mode when you need to maintain current traffic flow while your certificate is being issued. You can place the validation token at the well-known path on your existing web server, wait for ACM to validate and issue the certificate, and then update your DNS to point to CloudFront.
<note markdown=“1”> This setting only affects the initial certificate request. Once the DNS points to CloudFront, all future certificate renewals are automatically handled through CloudFront.
</note>
10885 10886 10887 10888 10889 10890 10891 10892 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 10885 class ManagedCertificateDetails < Struct.new( :certificate_arn, :certificate_status, :validation_token_host, :validation_token_details) SENSITIVE = [] include Aws::Structure end |