Class: Aws::CloudFront::Types::OriginAccessControlList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginAccessControlList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of CloudFront origin access controls.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
If there are more items in the list than are in this response, this value is
true. -
#items ⇒ Array<Types::OriginAccessControlSummary>
Contains the origin access controls in the list.
-
#marker ⇒ String
The value of the
Markerfield that was provided in the request. -
#max_items ⇒ Integer
The maximum number of origin access controls requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The number of origin access controls returned in the response.
Instance Attribute Details
#is_truncated ⇒ Boolean
If there are more items in the list than are in this response, this value is true.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::OriginAccessControlSummary>
Contains the origin access controls in the list.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The value of the Marker field that was provided in the request.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin access controls requested.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present. It contains the value to use in the Marker field of another request to continue listing origin access controls.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of origin access controls returned in the response.
11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11542 class OriginAccessControlList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |