Class: Aws::CloudFront::Types::OriginAccessControlSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginAccessControlSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A CloudFront origin access control.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the origin access control.
-
#id ⇒ String
The unique identifier of the origin access control.
-
#name ⇒ String
A unique name that identifies the origin access control.
-
#origin_access_control_origin_type ⇒ String
The type of origin that this origin access control is for.
-
#signing_behavior ⇒ String
A value that specifies which requests CloudFront signs (adds authentication information to).
-
#signing_protocol ⇒ String
The signing protocol of the origin access control.
Instance Attribute Details
#description ⇒ String
A description of the origin access control.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the origin access control.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name that identifies the origin access control.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |
#origin_access_control_origin_type ⇒ String
The type of origin that this origin access control is for.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |
#signing_behavior ⇒ String
A value that specifies which requests CloudFront signs (adds authentication information to). This field can have one of the following values:
-
never– CloudFront doesn’t sign any origin requests. -
always– CloudFront signs all origin requests, overwriting theAuthorizationheader from the viewer request if necessary. -
no-override– If the viewer request doesn’t contain theAuthorizationheader, CloudFront signs the origin request. If the viewer request contains theAuthorizationheader, CloudFront doesn’t sign the origin request, but instead passes along theAuthorizationheader that it received in the viewer request.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |
#signing_protocol ⇒ String
The signing protocol of the origin access control. The signing protocol determines how CloudFront signs (authenticates) requests. The only valid value is sigv4.
8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 8464 class OriginAccessControlSummary < Struct.new( :id, :description, :name, :signing_protocol, :signing_behavior, :origin_access_control_origin_type) SENSITIVE = [] include Aws::Structure end |