Class: Aws::CloudFront::Types::OriginMtlsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginMtlsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
Configures mutual TLS authentication between CloudFront and your origin server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the client certificate stored in Amazon Web Services Certificate Manager (ACM) that CloudFront uses to authenticate with your origin using Mutual TLS.
Instance Attribute Details
#client_certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the client certificate stored in Amazon Web Services Certificate Manager (ACM) that CloudFront uses to authenticate with your origin using Mutual TLS.
11816 11817 11818 11819 11820 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 11816 class OriginMtlsConfig < Struct.new( :client_certificate_arn) SENSITIVE = [] include Aws::Structure end |