Class: Aws::CloudFront::Types::OriginRequestPolicyList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A list of origin request policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::OriginRequestPolicySummary>

Contains the origin request policies in the list.



12004
12005
12006
12007
12008
12009
12010
12011
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004

class OriginRequestPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of origin request policies requested.

Returns:

  • (Integer)


12004
12005
12006
12007
12008
12009
12010
12011
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004

class OriginRequestPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing origin request policies where you left off.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004

class OriginRequestPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The total number of origin request policies returned in the response.

Returns:

  • (Integer)


12004
12005
12006
12007
12008
12009
12010
12011
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004

class OriginRequestPolicyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end