Class: Aws::CloudFront::Types::OriginRequestPolicyList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::OriginRequestPolicyList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of origin request policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::OriginRequestPolicySummary>
Contains the origin request policies in the list.
-
#max_items ⇒ Integer
The maximum number of origin request policies requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The total number of origin request policies returned in the response.
Instance Attribute Details
#items ⇒ Array<Types::OriginRequestPolicySummary>
Contains the origin request policies in the list.
12004 12005 12006 12007 12008 12009 12010 12011 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004 class OriginRequestPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of origin request policies requested.
12004 12005 12006 12007 12008 12009 12010 12011 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004 class OriginRequestPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing origin request policies where you left off.
12004 12005 12006 12007 12008 12009 12010 12011 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004 class OriginRequestPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The total number of origin request policies returned in the response.
12004 12005 12006 12007 12008 12009 12010 12011 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12004 class OriginRequestPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |