Class: Aws::CloudFront::Types::PublicKeyList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::PublicKeyList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of public keys that you can use with signed URLs and signed cookies, or with field-level encryption.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::PublicKeySummary>
A list of public keys.
-
#max_items ⇒ Integer
The maximum number of public keys you want in the response.
-
#next_marker ⇒ String
If there are more elements to be listed, this element is present and contains the value that you can use for the
Markerrequest parameter to continue listing your public keys where you left off. -
#quantity ⇒ Integer
The number of public keys in the list.
Instance Attribute Details
#items ⇒ Array<Types::PublicKeySummary>
A list of public keys.
12593 12594 12595 12596 12597 12598 12599 12600 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12593 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of public keys you want in the response.
12593 12594 12595 12596 12597 12598 12599 12600 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12593 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more elements to be listed, this element is present and
contains the value that you can use for the Marker request
parameter to continue listing your public keys where you left off.
12593 12594 12595 12596 12597 12598 12599 12600 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12593 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of public keys in the list.
12593 12594 12595 12596 12597 12598 12599 12600 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12593 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |