Class: Aws::CloudFront::Types::PublicKeyList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::PublicKeySummary>

A list of public keys.

Returns:



12533
12534
12535
12536
12537
12538
12539
12540
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533

class PublicKeyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of public keys you want in the response.

Returns:

  • (Integer)


12533
12534
12535
12536
12537
12538
12539
12540
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533

class PublicKeyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If there are more elements to be listed, this element is present and contains the value that you can use for the Marker request parameter to continue listing your public keys where you left off.

Returns:

  • (String)


12533
12534
12535
12536
12537
12538
12539
12540
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533

class PublicKeyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of public keys in the list.

Returns:

  • (Integer)


12533
12534
12535
12536
12537
12538
12539
12540
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533

class PublicKeyList < Struct.new(
  :next_marker,
  :max_items,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end