Class: Aws::CloudFront::Types::PublicKeyList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::PublicKeyList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of public keys that you can use with [signed URLs and signed cookies], or with [field-level encryption].
[1]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html [2]: docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::PublicKeySummary>
A list of public keys.
-
#max_items ⇒ Integer
The maximum number of public keys you want in the response.
-
#next_marker ⇒ String
If there are more elements to be listed, this element is present and contains the value that you can use for the
Markerrequest parameter to continue listing your public keys where you left off. -
#quantity ⇒ Integer
The number of public keys in the list.
Instance Attribute Details
#items ⇒ Array<Types::PublicKeySummary>
A list of public keys.
12533 12534 12535 12536 12537 12538 12539 12540 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of public keys you want in the response.
12533 12534 12535 12536 12537 12538 12539 12540 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more elements to be listed, this element is present and contains the value that you can use for the Marker request parameter to continue listing your public keys where you left off.
12533 12534 12535 12536 12537 12538 12539 12540 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of public keys in the list.
12533 12534 12535 12536 12537 12538 12539 12540 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12533 class PublicKeyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |