Class: Aws::CloudFront::Types::ResponseHeadersPolicyList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ResponseHeadersPolicyList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of response headers policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ResponseHeadersPolicySummary>
The response headers policies in the list.
-
#max_items ⇒ Integer
The maximum number of response headers policies requested.
-
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present.
-
#quantity ⇒ Integer
The number of response headers policies returned.
Instance Attribute Details
#items ⇒ Array<Types::ResponseHeadersPolicySummary>
The response headers policies in the list.
13505 13506 13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13505 class ResponseHeadersPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of response headers policies requested.
13505 13506 13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13505 class ResponseHeadersPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If there are more items in the list than are in this response, this element is present. It contains the value that you should use in the Marker field of a subsequent request to continue listing response headers policies where you left off.
13505 13506 13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13505 class ResponseHeadersPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of response headers policies returned.
13505 13506 13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13505 class ResponseHeadersPolicyList < Struct.new( :next_marker, :max_items, :quantity, :items) SENSITIVE = [] include Aws::Structure end |