Class: Aws::CloudFront::Types::ResponseHeadersPolicyRemoveHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

The name of an HTTP header that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#headerString

The HTTP header name.

Returns:

  • (String)


13621
13622
13623
13624
13625
# File 'lib/aws-sdk-cloudfront/types.rb', line 13621

class ResponseHeadersPolicyRemoveHeader < Struct.new(
  :header)
  SENSITIVE = []
  include Aws::Structure
end