Class: Aws::CloudFront::Types::ResponseHeadersPolicyRemoveHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::ResponseHeadersPolicyRemoveHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
The name of an HTTP header that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#header ⇒ String
The HTTP header name.
Instance Attribute Details
#header ⇒ String
The HTTP header name.
13621 13622 13623 13624 13625 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 13621 class ResponseHeadersPolicyRemoveHeader < Struct.new( :header) SENSITIVE = [] include Aws::Structure end |