Class: Aws::CloudFront::Types::StreamingDistributionList

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudfront/types.rb

Overview

A streaming distribution list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether more streaming distributions remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more distributions in the list.

Returns:

  • (Boolean)


14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::StreamingDistributionSummary>

A complex type that contains one StreamingDistributionSummary element for each distribution that was created by the current Amazon Web Services account.



14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The value you provided for the Marker request parameter.

Returns:

  • (String)


14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The value you provided for the MaxItems request parameter.

Returns:

  • (Integer)


14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your RTMP distributions where they left off.

Returns:

  • (String)


14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#quantityInteger

The number of streaming distributions that were created by the current Amazon Web Services account.

Returns:

  • (Integer)


14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329

class StreamingDistributionList < Struct.new(
  :marker,
  :next_marker,
  :max_items,
  :is_truncated,
  :quantity,
  :items)
  SENSITIVE = []
  include Aws::Structure
end