Class: Aws::CloudFront::Types::StreamingDistributionList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::StreamingDistributionList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A streaming distribution list.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more streaming distributions remain to be listed.
-
#items ⇒ Array<Types::StreamingDistributionSummary>
A complex type that contains one
StreamingDistributionSummaryelement for each distribution that was created by the current Amazon Web Services account. -
#marker ⇒ String
The value you provided for the
Markerrequest parameter. -
#max_items ⇒ Integer
The value you provided for the
MaxItemsrequest parameter. -
#next_marker ⇒ String
If
IsTruncatedistrue, this element is present and contains the value you can use for theMarkerrequest parameter to continue listing your RTMP distributions where they left off. -
#quantity ⇒ Integer
The number of streaming distributions that were created by the current Amazon Web Services account.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more streaming distributions remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more distributions in the list.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::StreamingDistributionSummary>
A complex type that contains one StreamingDistributionSummary element for each distribution that was created by the current Amazon Web Services account.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The value you provided for the Marker request parameter.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The value you provided for the MaxItems request parameter.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your RTMP distributions where they left off.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of streaming distributions that were created by the current Amazon Web Services account.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 14329 class StreamingDistributionList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |