Class: Aws::CloudFront::Types::TrustedKeyGroups
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::TrustedKeyGroups
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of key groups whose public keys CloudFront can use to verify the signatures of signed URLs and signed cookies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
This field is
trueif any of the key groups in the list have public keys that CloudFront can use to verify the signatures of signed URLs and signed cookies. -
#items ⇒ Array<String>
A list of key groups identifiers.
-
#quantity ⇒ Integer
The number of key groups in the list.
Instance Attribute Details
#enabled ⇒ Boolean
This field is true if any of the key groups in the list have public keys that CloudFront can use to verify the signatures of signed URLs and signed cookies. If not, this field is false.
12257 12258 12259 12260 12261 12262 12263 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257 class TrustedKeyGroups < Struct.new( :enabled, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<String>
A list of key groups identifiers.
12257 12258 12259 12260 12261 12262 12263 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257 class TrustedKeyGroups < Struct.new( :enabled, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of key groups in the list.
12257 12258 12259 12260 12261 12262 12263 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 12257 class TrustedKeyGroups < Struct.new( :enabled, :quantity, :items) SENSITIVE = [] include Aws::Structure end |