Class: Aws::CloudFront::Types::VpcOriginList
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFront::Types::VpcOriginList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudfront/types.rb
Overview
A list of CloudFront VPC origins.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether more VPC origins remain to be listed.
-
#items ⇒ Array<Types::VpcOriginSummary>
The items of the VPC origins list.
-
#marker ⇒ String
The marker associated with the VPC origins list.
-
#max_items ⇒ Integer
The maximum number of items included in the list.
-
#next_marker ⇒ String
The next marker associated with the VPC origins list.
-
#quantity ⇒ Integer
The number of VPC origins in the list.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether more VPC origins remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more VPC origins in the list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::VpcOriginSummary>
The items of the VPC origins list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The marker associated with the VPC origins list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of items included in the list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
The next marker associated with the VPC origins list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The number of VPC origins in the list.
17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 |
# File 'lib/aws-sdk-cloudfront/types.rb', line 17397 class VpcOriginList < Struct.new( :marker, :next_marker, :max_items, :is_truncated, :quantity, :items) SENSITIVE = [] include Aws::Structure end |